/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwell.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwell *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwell_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwell_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwell_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwell();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwell::Heavy_vSwell(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_UEbsjOr1, &hTable_PXRgFI6A);
  numBytes += sTabread_init(&sTabread_hkBzqMr5, &hTable_PXRgFI6A, true);
  numBytes += sRPole_init(&sRPole_VDG78TMH);
  numBytes += sEnv_init(&sEnv_ePpyDEXp, 1024, 512);
  numBytes += sLine_init(&sLine_me8UX50f);
  numBytes += cSlice_init(&cSlice_Uu4Jj8aw, 1, -1);
  numBytes += cSlice_init(&cSlice_IXt055CB, 1, -1);
  numBytes += cVar_init_f(&cVar_wjXJary9, 0.0f);
  numBytes += cIf_init(&cIf_HECLImbE, false);
  numBytes += cBinop_init(&cBinop_2Nf5F6c2, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_jud13r1I, 1, -1);
  numBytes += cSlice_init(&cSlice_DGRbILaT, 1, -1);
  numBytes += cVar_init_f(&cVar_yQoYWsh1, 0.0f);
  numBytes += cIf_init(&cIf_5lCY8zjd, false);
  numBytes += cBinop_init(&cBinop_yRVwFP9r, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_jQ7MIox4, 0.0f);
  numBytes += cVar_init_f(&cVar_P41wmj69, 0.0f);
  numBytes += cBinop_init(&cBinop_XiFaXkH0, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_FMxrERt2, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_cfynjru7, 2, 1);
  numBytes += cSlice_init(&cSlice_sAqqF38L, 1, 1);
  numBytes += cSlice_init(&cSlice_9ipibQEh, 0, 1);
  numBytes += cVar_init_f(&cVar_kT9NfjCq, 0.0f);
  numBytes += cIf_init(&cIf_VR3gYaK7, false);
  numBytes += cIf_init(&cIf_E9ObS3Fz, false);
  numBytes += cIf_init(&cIf_g1vHvQTe, false);
  numBytes += cIf_init(&cIf_Y6VvpZz3, false);
  numBytes += cIf_init(&cIf_LVAdJGhY, false);
  numBytes += cBinop_init(&cBinop_DQOpxDlT, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_MW8oc8F7, 10.0f);
  numBytes += cPack_init(&cPack_FPyrmsc3, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_ub2zRqjI, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_g3awnApV, 10.0f);
  numBytes += cPack_init(&cPack_kBIeLvni, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_GMFLd6EQ, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_ULuCTqlh, 10.0f);
  numBytes += cPack_init(&cPack_rfqMdhPV, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_XRzMwq3t, 1e-07f);
  numBytes += cIf_init(&cIf_tg0VIbfj, true);
  numBytes += cVar_init_f(&cVar_zHaMYvIY, 1e-07f);
  numBytes += cVar_init_f(&cVar_EkB5m8uY, 1e-07f);
  numBytes += sVarf_init(&sVarf_Q8ZOr4ht, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_eWzXwy62, 0.0f);
  numBytes += cVar_init_f(&cVar_7aYBvT3j, 20.0f);
  numBytes += cBinop_init(&cBinop_7ZIjMUba, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_X0VsF8Fz, 0.0f);
  numBytes += cSlice_init(&cSlice_q5LA2RzL, 1, -1);
  numBytes += cSlice_init(&cSlice_xJW9dQbA, 1, -1);
  numBytes += cVar_init_f(&cVar_Wiy9Qmm4, 0.0f);
  numBytes += cVar_init_f(&cVar_AvMzeZxA, 20.0f);
  numBytes += cVar_init_f(&cVar_IE5hjw3h, 0.0f);
  numBytes += cVar_init_f(&cVar_BYVQ4Ra4, 0.0f);
  numBytes += cVar_init_f(&cVar_VWbRcNIW, 0.0f);
  numBytes += cSlice_init(&cSlice_3HezCOSF, 1, 1);
  numBytes += cSlice_init(&cSlice_w29NZHPg, 0, 1);
  numBytes += cBinop_init(&cBinop_O4y2LC2g, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Zj2qWfAM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aVM9Uzo9, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_OO7PaYUm, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_iaqx4uIW, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_GwJNeEMq, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_QBkviOvR, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_geS9ed1b, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_NJO0oIIn, 5.0f);
  numBytes += cVar_init_f(&cVar_BDKSnSOD, 500.0f);
  numBytes += cBinop_init(&cBinop_tKTNayme, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_FmbjY9li, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bvRfZlHm, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_MP5eADuI, 0.0f);
  numBytes += cDelay_init(this, &cDelay_IBzlppnP, 0.0f);
  numBytes += hTable_init(&hTable_PXRgFI6A, 256);
  numBytes += cTabhead_init(&cTabhead_cDcl6iM9, &hTable_PXRgFI6A);
  numBytes += cVar_init_s(&cVar_oyiSRas3, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_otpkRBlP, 8.0f);
  numBytes += cDelay_init(this, &cDelay_O1vJ7wE9, 0.0f);
  numBytes += cBinop_init(&cBinop_umZzNCGC, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_2ELgAXvC, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_tnwAkLNK, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Gq5pDSO2, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_8mneE2nz, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_8bMDQyyL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QhUI3HOE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OUFLFBNi, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwell::~Heavy_vSwell() {
  sEnv_free(&sEnv_ePpyDEXp);
  cPack_free(&cPack_FPyrmsc3);
  cPack_free(&cPack_kBIeLvni);
  cPack_free(&cPack_rfqMdhPV);
  hTable_free(&hTable_PXRgFI6A);
}

HvTable *Heavy_vSwell::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_PXRgFI6A; // del-1001-swell
    default: return nullptr;
  }
}

void Heavy_vSwell::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MiC3u1AM_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AlQ9iANC_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LSrNYoaD_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a88RFbQo_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7TUdPCWq_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_prNePp7O_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6RfggKbg_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6ZW2gXMk_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5bF4ikBL_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Dxqf1mka_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jary6kJ5_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QMiLNtoR_sendMessage);
      break;
    }
    case 0xE7A7BB75: { // Trigger_by_Audio_ON
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RbawrbhQ_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tmbtEAQ1_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HwyWST9v_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dUiyvnoW_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eTjLPxJM_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwell::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 30.0f;
        info->maxVal = 85.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_by_Audio_ON";
        info->hash = 0xE7A7BB75;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 13;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwell::sEnv_ePpyDEXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XiFaXkH0, HV_BINOP_GREATER_THAN, 0, m, &cBinop_XiFaXkH0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FMxrERt2, HV_BINOP_LESS_THAN, 0, m, &cBinop_FMxrERt2_sendMessage);
}

void Heavy_vSwell::cSwitchcase_pgK0iZ62_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Uu4Jj8aw, 0, m, &cSlice_Uu4Jj8aw_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IXt055CB, 0, m, &cSlice_IXt055CB_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EzyXmHhR_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GVtmPZGu_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_Uu4Jj8aw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_wjXJary9, 0, m, &cVar_wjXJary9_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_wjXJary9, 0, m, &cVar_wjXJary9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_IXt055CB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2Nf5F6c2, HV_BINOP_NEQ, 1, m, &cBinop_2Nf5F6c2_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wjXJary9, 1, m, &cVar_wjXJary9_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2Nf5F6c2, HV_BINOP_NEQ, 1, m, &cBinop_2Nf5F6c2_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wjXJary9, 1, m, &cVar_wjXJary9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_wjXJary9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9xKeAbxu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_HECLImbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tfs5idit_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KdZSziUd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_tfs5idit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Nf5F6c2, HV_BINOP_NEQ, 1, m, &cBinop_2Nf5F6c2_sendMessage);
}

void Heavy_vSwell::cCast_KdZSziUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wjXJary9, 0, m, &cVar_wjXJary9_sendMessage);
}

void Heavy_vSwell::cBinop_2Nf5F6c2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HECLImbE, 1, m, &cIf_HECLImbE_sendMessage);
}

void Heavy_vSwell::cCast_GVtmPZGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HECLImbE, 0, m, &cIf_HECLImbE_sendMessage);
}

void Heavy_vSwell::cCast_EzyXmHhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Nf5F6c2, HV_BINOP_NEQ, 0, m, &cBinop_2Nf5F6c2_sendMessage);
}

void Heavy_vSwell::cSwitchcase_ZClvd2qa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jud13r1I, 0, m, &cSlice_jud13r1I_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DGRbILaT, 0, m, &cSlice_DGRbILaT_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k7kPqyP6_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ysawfSzr_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_jud13r1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_yQoYWsh1, 0, m, &cVar_yQoYWsh1_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_yQoYWsh1, 0, m, &cVar_yQoYWsh1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_DGRbILaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yRVwFP9r, HV_BINOP_NEQ, 1, m, &cBinop_yRVwFP9r_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_yQoYWsh1, 1, m, &cVar_yQoYWsh1_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yRVwFP9r, HV_BINOP_NEQ, 1, m, &cBinop_yRVwFP9r_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_yQoYWsh1, 1, m, &cVar_yQoYWsh1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_yQoYWsh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DjMEg4Ar_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_5lCY8zjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5en8He67_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ivd07cpZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_ivd07cpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yQoYWsh1, 0, m, &cVar_yQoYWsh1_sendMessage);
}

void Heavy_vSwell::cCast_5en8He67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yRVwFP9r, HV_BINOP_NEQ, 1, m, &cBinop_yRVwFP9r_sendMessage);
}

void Heavy_vSwell::cBinop_yRVwFP9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5lCY8zjd, 1, m, &cIf_5lCY8zjd_sendMessage);
}

void Heavy_vSwell::cCast_k7kPqyP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yRVwFP9r, HV_BINOP_NEQ, 0, m, &cBinop_yRVwFP9r_sendMessage);
}

void Heavy_vSwell::cCast_ysawfSzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5lCY8zjd, 0, m, &cIf_5lCY8zjd_sendMessage);
}

void Heavy_vSwell::cSwitchcase_9xKeAbxu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A2LYequn_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ubfY3lE3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_A2LYequn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P41wmj69, 0, m, &cVar_P41wmj69_sendMessage);
}

void Heavy_vSwell::cCast_ubfY3lE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9tMyqUzq_sendMessage(_c, 0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tg0VIbfj, 0, m, &cIf_tg0VIbfj_sendMessage);
}

void Heavy_vSwell::cSwitchcase_DjMEg4Ar_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tezDin9q_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NApC7emK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_tezDin9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jQ7MIox4, 0, m, &cVar_jQ7MIox4_sendMessage);
}

void Heavy_vSwell::cCast_NApC7emK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BKtBN38F_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_jQ7MIox4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XiFaXkH0, HV_BINOP_GREATER_THAN, 1, m, &cBinop_XiFaXkH0_sendMessage);
}

void Heavy_vSwell::cVar_P41wmj69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FMxrERt2, HV_BINOP_LESS_THAN, 1, m, &cBinop_FMxrERt2_sendMessage);
}

void Heavy_vSwell::cBinop_XiFaXkH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pgK0iZ62_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_FMxrERt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZClvd2qa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_9tMyqUzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XiFaXkH0, HV_BINOP_GREATER_THAN, 1, m, &cBinop_XiFaXkH0_sendMessage);
}

void Heavy_vSwell::cMsg_BKtBN38F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FMxrERt2, HV_BINOP_LESS_THAN, 1, m, &cBinop_FMxrERt2_sendMessage);
}

void Heavy_vSwell::cSlice_cfynjru7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CXnDcmRD_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_sAqqF38L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_Y6VvpZz3, 0, m, &cIf_Y6VvpZz3_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_E9ObS3Fz, 0, m, &cIf_E9ObS3Fz_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_9ipibQEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_LVAdJGhY, 0, m, &cIf_LVAdJGhY_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_g1vHvQTe, 0, m, &cIf_g1vHvQTe_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_kT9NfjCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lT3etGgk_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VR3gYaK7, 0, m, &cIf_VR3gYaK7_sendMessage);
}

void Heavy_vSwell::cUnop_hOgGhZIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8OJV9QII_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DQOpxDlT, HV_BINOP_EQ, 1, m, &cBinop_DQOpxDlT_sendMessage);
}

void Heavy_vSwell::cUnop_jFaPdohb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8OJV9QII_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DQOpxDlT, HV_BINOP_EQ, 1, m, &cBinop_DQOpxDlT_sendMessage);
}

void Heavy_vSwell::cIf_VR3gYaK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_jFaPdohb_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_hOgGhZIg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_lT3etGgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VR3gYaK7, 1, m, &cIf_VR3gYaK7_sendMessage);
}

void Heavy_vSwell::cIf_E9ObS3Fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rUlgCHmi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_g1vHvQTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_Y6VvpZz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rUlgCHmi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_LVAdJGhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_CXnDcmRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DQOpxDlT, HV_BINOP_EQ, 0, m, &cBinop_DQOpxDlT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_sesBpOeF_sendMessage);
}

void Heavy_vSwell::cBinop_8OJV9QII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YmVcmqtp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uFH4JmGB_sendMessage);
}

void Heavy_vSwell::cBinop_DQOpxDlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KVjLoxhX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RuJO8cpF_sendMessage);
}

void Heavy_vSwell::cCast_RuJO8cpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LVAdJGhY, 1, m, &cIf_LVAdJGhY_sendMessage);
}

void Heavy_vSwell::cCast_KVjLoxhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E9ObS3Fz, 1, m, &cIf_E9ObS3Fz_sendMessage);
}

void Heavy_vSwell::cCast_uFH4JmGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g1vHvQTe, 1, m, &cIf_g1vHvQTe_sendMessage);
}

void Heavy_vSwell::cCast_YmVcmqtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y6VvpZz3, 1, m, &cIf_Y6VvpZz3_sendMessage);
}

void Heavy_vSwell::cBinop_sesBpOeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwell::cSwitchcase_tcZrTjEr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jcKnbtfu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jcKnbtfu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MW8oc8F7, 1, m, &cDelay_MW8oc8F7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a02nRgSW_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_MW8oc8F7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MW8oc8F7, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jYcRBYve_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pj1BS4Gw_sendMessage);
  cSwitchcase_6AVYkcjf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_jcKnbtfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MW8oc8F7, 0, m, &cDelay_MW8oc8F7_sendMessage);
}

void Heavy_vSwell::cCast_a02nRgSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MW8oc8F7, 0, m, &cDelay_MW8oc8F7_sendMessage);
}

void Heavy_vSwell::cPack_FPyrmsc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EWS9pVKH_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_ub2zRqjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QBuStfMh_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_tOZTiGqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_tcZrTjEr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_38U7EXYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_FPyrmsc3, 0, m, &cPack_FPyrmsc3_sendMessage);
}

void Heavy_vSwell::cCast_CsJS5sIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ub2zRqjI, 0, m, &cVar_ub2zRqjI_sendMessage);
}

void Heavy_vSwell::cMsg_QBuStfMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_me8UX50f, 0, m, NULL);
}

void Heavy_vSwell::cMsg_EWS9pVKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_me8UX50f, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_6AVYkcjf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tBZzLyxV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tBZzLyxV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_g3awnApV, 1, m, &cDelay_g3awnApV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LraupMBz_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_g3awnApV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_g3awnApV, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_172F5S1r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_syHw9Gjf_sendMessage);
  cSwitchcase_AKuSgbz1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_tBZzLyxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_g3awnApV, 0, m, &cDelay_g3awnApV_sendMessage);
}

void Heavy_vSwell::cCast_LraupMBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_g3awnApV, 0, m, &cDelay_g3awnApV_sendMessage);
}

void Heavy_vSwell::cPack_kBIeLvni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wR3jzt0k_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_GMFLd6EQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y5LNTlEd_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_IuhJYfFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_6AVYkcjf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_Pj1BS4Gw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_kBIeLvni, 0, m, &cPack_kBIeLvni_sendMessage);
}

void Heavy_vSwell::cCast_jYcRBYve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GMFLd6EQ, 0, m, &cVar_GMFLd6EQ_sendMessage);
}

void Heavy_vSwell::cMsg_Y5LNTlEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_me8UX50f, 0, m, NULL);
}

void Heavy_vSwell::cMsg_wR3jzt0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_me8UX50f, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_AKuSgbz1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0mitxckj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0mitxckj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ULuCTqlh, 1, m, &cDelay_ULuCTqlh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gOZap9Lh_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_ULuCTqlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ULuCTqlh, m);
}

void Heavy_vSwell::cMsg_0mitxckj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ULuCTqlh, 0, m, &cDelay_ULuCTqlh_sendMessage);
}

void Heavy_vSwell::cCast_gOZap9Lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ULuCTqlh, 0, m, &cDelay_ULuCTqlh_sendMessage);
}

void Heavy_vSwell::cPack_rfqMdhPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q1UPOY5O_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_XRzMwq3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YJuRNkJY_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_jriZLL9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_AKuSgbz1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_172F5S1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XRzMwq3t, 0, m, &cVar_XRzMwq3t_sendMessage);
}

void Heavy_vSwell::cCast_syHw9Gjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_rfqMdhPV, 0, m, &cPack_rfqMdhPV_sendMessage);
}

void Heavy_vSwell::cMsg_YJuRNkJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_me8UX50f, 0, m, NULL);
}

void Heavy_vSwell::cMsg_q1UPOY5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_me8UX50f, 0, m, NULL);
}

void Heavy_vSwell::cIf_tg0VIbfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8WtpYl8Z_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xiXQZJTb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSwitchcase_YGGkG6ma_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7wPcoCfF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_7wPcoCfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8WtpYl8Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xiXQZJTb_sendMessage);
}

void Heavy_vSwell::cVar_zHaMYvIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HCAmlVin_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_EkB5m8uY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_rfqMdhPV, 1, m, &cPack_rfqMdhPV_sendMessage);
}

void Heavy_vSwell::cMsg_9eCRDIGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xwkbDPsH_sendMessage);
}

void Heavy_vSwell::cSystem_xwkbDPsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zj2qWfAM, HV_BINOP_MULTIPLY, 1, m, &cBinop_Zj2qWfAM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O4y2LC2g, HV_BINOP_MULTIPLY, 1, m, &cBinop_O4y2LC2g_sendMessage);
}

void Heavy_vSwell::cSwitchcase_TN6cbJEU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_at2k2tod_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_at2k2tod_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GYqy5YPo_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_eWzXwy62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eWzXwy62, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eWzXwy62, 0, m, &cDelay_eWzXwy62_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_X0VsF8Fz, 0, m, &cVar_X0VsF8Fz_sendMessage);
}

void Heavy_vSwell::cCast_GYqy5YPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_at2k2tod_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eWzXwy62, 0, m, &cDelay_eWzXwy62_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_X0VsF8Fz, 0, m, &cVar_X0VsF8Fz_sendMessage);
}

void Heavy_vSwell::cMsg_qINn6pjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0atv6oo9_sendMessage);
}

void Heavy_vSwell::cSystem_0atv6oo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_w7MYjxlG_sendMessage);
}

void Heavy_vSwell::cVar_7aYBvT3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ZIjMUba, HV_BINOP_MULTIPLY, 0, m, &cBinop_7ZIjMUba_sendMessage);
}

void Heavy_vSwell::cMsg_at2k2tod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eWzXwy62, 0, m, &cDelay_eWzXwy62_sendMessage);
}

void Heavy_vSwell::cBinop_pol6gPLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eWzXwy62, 2, m, &cDelay_eWzXwy62_sendMessage);
}

void Heavy_vSwell::cBinop_w7MYjxlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ZIjMUba, HV_BINOP_MULTIPLY, 1, m, &cBinop_7ZIjMUba_sendMessage);
}

void Heavy_vSwell::cBinop_7ZIjMUba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_pol6gPLF_sendMessage);
}

void Heavy_vSwell::cVar_X0VsF8Fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aVM9Uzo9, HV_BINOP_SUBTRACT, 0, m, &cBinop_aVM9Uzo9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_qbiOGUhN_sendMessage);
}

void Heavy_vSwell::cSwitchcase_sGNnA0BP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HjH4tlco_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qYREEGiP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_HjH4tlco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VWbRcNIW, 0, m, &cVar_VWbRcNIW_sendMessage);
}

void Heavy_vSwell::cCast_qYREEGiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tAJfbKpB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_na42v29B_sendMessage);
}

void Heavy_vSwell::cSwitchcase_M5fKNfbg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_q5LA2RzL, 0, m, &cSlice_q5LA2RzL_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xJW9dQbA, 0, m, &cSlice_xJW9dQbA_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d7dnClct_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_3HezCOSF, 0, m, &cSlice_3HezCOSF_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_w29NZHPg, 0, m, &cSlice_w29NZHPg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F2SclQpG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YQKYa5CM_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_q5LA2RzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_q2hzGDqI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_q2hzGDqI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_xJW9dQbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zzjX7vCI_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gwd7zb1W_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zzjX7vCI_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gwd7zb1W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_Wiy9Qmm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1ZNy2BzH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KxVMFRMi_sendMessage);
}

void Heavy_vSwell::cVar_AvMzeZxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RlzE475E_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_RlzE475E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1qVl3J9l_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Zj2qWfAM, HV_BINOP_MULTIPLY, 0, m, &cBinop_Zj2qWfAM_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_iaqx4uIW, HV_BINOP_DIVIDE, 1, m, &cBinop_iaqx4uIW_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_7aYBvT3j, 0, m, &cVar_7aYBvT3j_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cCast_1qVl3J9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_utMOPBRM_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_IE5hjw3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_geS9ed1b, HV_BINOP_SUBTRACT, 1, m, &cBinop_geS9ed1b_sendMessage);
}

void Heavy_vSwell::cVar_BYVQ4Ra4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VWbRcNIW, 0, m, &cVar_VWbRcNIW_sendMessage);
}

void Heavy_vSwell::cVar_VWbRcNIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OO7PaYUm, HV_BINOP_ADD, 0, m, &cBinop_OO7PaYUm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QBkviOvR, HV_BINOP_ADD, 0, m, &cBinop_QBkviOvR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Q8ZOr4ht, m);
}

void Heavy_vSwell::cSlice_3HezCOSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1ZNy2BzH_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KxVMFRMi_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_w29NZHPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tcyFtO51_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ146Hgh_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_suujtG7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X0VsF8Fz, 1, m, &cVar_X0VsF8Fz_sendMessage);
}

void Heavy_vSwell::cBinop_O4y2LC2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_suujtG7g_sendMessage);
}

void Heavy_vSwell::cBinop_Zj2qWfAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cdeHj2Im_sendMessage);
}

void Heavy_vSwell::cBinop_cdeHj2Im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aVM9Uzo9, HV_BINOP_SUBTRACT, 1, m, &cBinop_aVM9Uzo9_sendMessage);
}

void Heavy_vSwell::cBinop_aVM9Uzo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X0VsF8Fz, 1, m, &cVar_X0VsF8Fz_sendMessage);
}

void Heavy_vSwell::cMsg_3rdsuzjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_TN6cbJEU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_hiiPxlCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_TN6cbJEU_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QBkviOvR, HV_BINOP_ADD, 1, m, &cBinop_QBkviOvR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OO7PaYUm, HV_BINOP_ADD, 1, m, &cBinop_OO7PaYUm_sendMessage);
}

void Heavy_vSwell::cBinop_qbiOGUhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sGNnA0BP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_OO7PaYUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VWbRcNIW, 1, m, &cVar_VWbRcNIW_sendMessage);
}

void Heavy_vSwell::cBinop_iaqx4uIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GwJNeEMq, HV_BINOP_DIVIDE, 1, m, &cBinop_GwJNeEMq_sendMessage);
}

void Heavy_vSwell::cBinop_GwJNeEMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QBkviOvR, HV_BINOP_ADD, 1, m, &cBinop_QBkviOvR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OO7PaYUm, HV_BINOP_ADD, 1, m, &cBinop_OO7PaYUm_sendMessage);
}

void Heavy_vSwell::cCast_KxVMFRMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iaqx4uIW, HV_BINOP_DIVIDE, 0, m, &cBinop_iaqx4uIW_sendMessage);
}

void Heavy_vSwell::cCast_1ZNy2BzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O4y2LC2g, HV_BINOP_MULTIPLY, 0, m, &cBinop_O4y2LC2g_sendMessage);
}

void Heavy_vSwell::cCast_zQ146Hgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_geS9ed1b, HV_BINOP_SUBTRACT, 0, m, &cBinop_geS9ed1b_sendMessage);
}

void Heavy_vSwell::cCast_tcyFtO51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BYVQ4Ra4, 1, m, &cVar_BYVQ4Ra4_sendMessage);
}

void Heavy_vSwell::cCast_tAJfbKpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hiiPxlCo_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_na42v29B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BYVQ4Ra4, 0, m, &cVar_BYVQ4Ra4_sendMessage);
}

void Heavy_vSwell::cBinop_QBkviOvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IE5hjw3h, 0, m, &cVar_IE5hjw3h_sendMessage);
}

void Heavy_vSwell::cMsg_q2hzGDqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_TN6cbJEU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_7jHP0R6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Wiy9Qmm4, 1, m, &cVar_Wiy9Qmm4_sendMessage);
}

void Heavy_vSwell::cMsg_utMOPBRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zj2qWfAM, HV_BINOP_MULTIPLY, 0, m, &cBinop_Zj2qWfAM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iaqx4uIW, HV_BINOP_DIVIDE, 1, m, &cBinop_iaqx4uIW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7aYBvT3j, 0, m, &cVar_7aYBvT3j_sendMessage);
}

void Heavy_vSwell::cCast_zzjX7vCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q2hzGDqI_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_Gwd7zb1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZXbB0o9X_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QBkviOvR, HV_BINOP_ADD, 0, m, &cBinop_QBkviOvR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VWbRcNIW, 1, m, &cVar_VWbRcNIW_sendMessage);
}

void Heavy_vSwell::cBinop_geS9ed1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GwJNeEMq, HV_BINOP_DIVIDE, 0, m, &cBinop_GwJNeEMq_sendMessage);
}

void Heavy_vSwell::cCast_ZXbB0o9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hiiPxlCo_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_YQKYa5CM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7jHP0R6K_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_F2SclQpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3rdsuzjY_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_d7dnClct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wiy9Qmm4, 0, m, &cVar_Wiy9Qmm4_sendMessage);
}

void Heavy_vSwell::cSwitchcase_3ZOzICy9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_98Kw9RER_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_98Kw9RER_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NJO0oIIn, 1, m, &cDelay_NJO0oIIn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EE0F2QGD_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_NJO0oIIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NJO0oIIn, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CsJS5sIY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_38U7EXYm_sendMessage);
  cSwitchcase_tcZrTjEr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_98Kw9RER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NJO0oIIn, 0, m, &cDelay_NJO0oIIn_sendMessage);
}

void Heavy_vSwell::cCast_EE0F2QGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NJO0oIIn, 0, m, &cDelay_NJO0oIIn_sendMessage);
}

void Heavy_vSwell::cVar_BDKSnSOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tKTNayme, HV_BINOP_MULTIPLY, 0, m, &cBinop_tKTNayme_sendMessage);
}

void Heavy_vSwell::cMsg_ziuprGem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dw73zbi9_sendMessage);
}

void Heavy_vSwell::cSystem_dw73zbi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ay69JyIn_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_tKTNayme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_VPbTrBAe_sendMessage);
}

void Heavy_vSwell::cBinop_ti2NE1e8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tKTNayme, HV_BINOP_MULTIPLY, 1, m, &cBinop_tKTNayme_sendMessage);
}

void Heavy_vSwell::cMsg_ay69JyIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ti2NE1e8_sendMessage);
}

void Heavy_vSwell::cBinop_VPbTrBAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_iMsFORiS_sendMessage);
}

void Heavy_vSwell::cBinop_iMsFORiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_e2YnIfDJ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bvRfZlHm, m);
}

void Heavy_vSwell::cBinop_e2YnIfDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FmbjY9li, m);
}

void Heavy_vSwell::cMsg_01lhIAmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MEOWplmm_sendMessage);
}

void Heavy_vSwell::cSystem_MEOWplmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_v0HymPBi_sendMessage);
}

void Heavy_vSwell::cDelay_MP5eADuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MP5eADuI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IBzlppnP, 0, m, &cDelay_IBzlppnP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MP5eADuI, 0, m, &cDelay_MP5eADuI_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UEbsjOr1, 1, m, NULL);
}

void Heavy_vSwell::cDelay_IBzlppnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IBzlppnP, m);
  cMsg_KqMSFSDm_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cSwitchcase_LTO94ZrC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_iyI7HJSb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cBinop_1VwpJ8Eb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5EoejoQP_sendMessage(_c, 0, m);
}

void Heavy_vSwell::hTable_PXRgFI6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b4TbwzJn_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MP5eADuI, 2, m, &cDelay_MP5eADuI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7RTu2RHW_sendMessage);
}

void Heavy_vSwell::cMsg_5EoejoQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_PXRgFI6A, 0, m, &hTable_PXRgFI6A_sendMessage);
}

void Heavy_vSwell::cBinop_v0HymPBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_1VwpJ8Eb_sendMessage);
}

void Heavy_vSwell::cMsg_KqMSFSDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_PXRgFI6A, 0, m, &hTable_PXRgFI6A_sendMessage);
}

void Heavy_vSwell::cCast_7RTu2RHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MP5eADuI, 0, m, &cDelay_MP5eADuI_sendMessage);
}

void Heavy_vSwell::cMsg_b4TbwzJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_IBzlppnP, 2, m, &cDelay_IBzlppnP_sendMessage);
}

void Heavy_vSwell::cMsg_iyI7HJSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UEbsjOr1, 1, m, NULL);
}

void Heavy_vSwell::cTabhead_cDcl6iM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2ELgAXvC, HV_BINOP_SUBTRACT, 0, m, &cBinop_2ELgAXvC_sendMessage);
}

void Heavy_vSwell::cMsg_YaI2dxea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_w8bbq0iI_sendMessage);
}

void Heavy_vSwell::cSystem_w8bbq0iI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cV0GX30i_sendMessage);
}

void Heavy_vSwell::cVar_oyiSRas3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jENjIq4s_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cDelay_otpkRBlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_otpkRBlP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O1vJ7wE9, 0, m, &cDelay_O1vJ7wE9_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hkBzqMr5, 0, m, &sTabread_hkBzqMr5_sendMessage);
}

void Heavy_vSwell::cDelay_O1vJ7wE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_O1vJ7wE9, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hkBzqMr5, 0, m, &sTabread_hkBzqMr5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O1vJ7wE9, 0, m, &cDelay_O1vJ7wE9_sendMessage);
}

void Heavy_vSwell::sTabread_hkBzqMr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Gq5pDSO2, HV_BINOP_SUBTRACT, 0, m, &cBinop_Gq5pDSO2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_umZzNCGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tnwAkLNK, HV_BINOP_MAX, 0, m, &cBinop_tnwAkLNK_sendMessage);
}

void Heavy_vSwell::cBinop_cV0GX30i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_umZzNCGC, HV_BINOP_MULTIPLY, 0, m, &cBinop_umZzNCGC_sendMessage);
}

void Heavy_vSwell::cBinop_2ELgAXvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PmsR34Yb_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hkBzqMr5, 0, m, &sTabread_hkBzqMr5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RCHshgXc_sendMessage);
}

void Heavy_vSwell::cSystem_MGyDBC7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gq5pDSO2, HV_BINOP_SUBTRACT, 1, m, &cBinop_Gq5pDSO2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O1vJ7wE9, 2, m, &cDelay_O1vJ7wE9_sendMessage);
}

void Heavy_vSwell::cMsg_jENjIq4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MGyDBC7f_sendMessage);
}

void Heavy_vSwell::cMsg_PmsR34Yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_otpkRBlP, 0, m, &cDelay_otpkRBlP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O1vJ7wE9, 0, m, &cDelay_O1vJ7wE9_sendMessage);
}

void Heavy_vSwell::cMsg_WUky3Iqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_tnwAkLNK, HV_BINOP_MAX, 1, m, &cBinop_tnwAkLNK_sendMessage);
}

void Heavy_vSwell::cBinop_tnwAkLNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2ELgAXvC, HV_BINOP_SUBTRACT, 1, m, &cBinop_2ELgAXvC_sendMessage);
}

void Heavy_vSwell::cCast_RCHshgXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_otpkRBlP, 0, m, &cDelay_otpkRBlP_sendMessage);
}

void Heavy_vSwell::cBinop_QIVPtMbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_otpkRBlP, 2, m, &cDelay_otpkRBlP_sendMessage);
}

void Heavy_vSwell::cBinop_Gq5pDSO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QIVPtMbg_sendMessage);
}

void Heavy_vSwell::cCast_vjWr0W5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oyiSRas3, 0, m, &cVar_oyiSRas3_sendMessage);
  cMsg_YaI2dxea_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_cDcl6iM9, 0, m, &cTabhead_cDcl6iM9_sendMessage);
}

void Heavy_vSwell::cUnop_epwXeqpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QhUI3HOE, m);
}

void Heavy_vSwell::cCast_xiXQZJTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3ZOzICy9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_8WtpYl8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sg2KSVYg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zHaMYvIY, 0, m, &cVar_zHaMYvIY_sendMessage);
}

void Heavy_vSwell::cCast_6XUUT18t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8mneE2nz, HV_BINOP_SUBTRACT, 0, m, &cBinop_8mneE2nz_sendMessage);
}

void Heavy_vSwell::cCast_49nNpgFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jQ7MIox4, 0, m, &cVar_jQ7MIox4_sendMessage);
}

void Heavy_vSwell::cBinop_8mneE2nz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P41wmj69, 0, m, &cVar_P41wmj69_sendMessage);
}

void Heavy_vSwell::cSend_sg2KSVYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dUiyvnoW_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_rUlgCHmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YGGkG6ma_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_o1lgZdCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_M5fKNfbg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_HCAmlVin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_me8UX50f, 0, m, NULL);
}

void Heavy_vSwell::cSend_jaegyV8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eTjLPxJM_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_dKijF4UR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NJO0oIIn, 1, m, &cDelay_NJO0oIIn_sendMessage);
}

void Heavy_vSwell::cBinop_ygjR6yq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_epwXeqpy_sendMessage);
}

void Heavy_vSwell::cReceive_5bF4ikBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8mneE2nz, HV_BINOP_SUBTRACT, 1, m, &cBinop_8mneE2nz_sendMessage);
}

void Heavy_vSwell::cReceive_tmbtEAQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qINn6pjN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7aYBvT3j, 0, m, &cVar_7aYBvT3j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kT9NfjCq, 0, m, &cVar_kT9NfjCq_sendMessage);
  cMsg_9eCRDIGe_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IE5hjw3h, 0, m, &cVar_IE5hjw3h_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AvMzeZxA, 0, m, &cVar_AvMzeZxA_sendMessage);
  cMsg_ziuprGem_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BDKSnSOD, 0, m, &cVar_BDKSnSOD_sendMessage);
  cMsg_01lhIAmi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_EkB5m8uY, 0, m, &cVar_EkB5m8uY_sendMessage);
  cMsg_WUky3Iqx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oyiSRas3, 0, m, &cVar_oyiSRas3_sendMessage);
  cMsg_YaI2dxea_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_cDcl6iM9, 0, m, &cTabhead_cDcl6iM9_sendMessage);
}

void Heavy_vSwell::cReceive_HwyWST9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_cfynjru7, 0, m, &cSlice_cfynjru7_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_sAqqF38L, 0, m, &cSlice_sAqqF38L_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_9ipibQEh, 0, m, &cSlice_9ipibQEh_sendMessage);
}

void Heavy_vSwell::cReceive_prNePp7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8bMDQyyL, m);
}

void Heavy_vSwell::cReceive_dUiyvnoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tOZTiGqu_sendMessage(_c, 0, m);
  cMsg_IuhJYfFU_sendMessage(_c, 0, m);
  cMsg_jriZLL9X_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_6ZW2gXMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6XUUT18t_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_49nNpgFb_sendMessage);
}

void Heavy_vSwell::cReceive_QMiLNtoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8WtpYl8Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xiXQZJTb_sendMessage);
}

void Heavy_vSwell::cReceive_RbawrbhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tg0VIbfj, 1, m, &cIf_tg0VIbfj_sendMessage);
}

void Heavy_vSwell::cReceive_MiC3u1AM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GMFLd6EQ, 1, m, &cVar_GMFLd6EQ_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_FPyrmsc3, 1, m, &cPack_FPyrmsc3_sendMessage);
}

void Heavy_vSwell::cReceive_AlQ9iANC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_FPyrmsc3, 2, m, &cPack_FPyrmsc3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MW8oc8F7, 1, m, &cDelay_MW8oc8F7_sendMessage);
}

void Heavy_vSwell::cReceive_LSrNYoaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_kBIeLvni, 1, m, &cPack_kBIeLvni_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XRzMwq3t, 1, m, &cVar_XRzMwq3t_sendMessage);
}

void Heavy_vSwell::cReceive_a88RFbQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_kBIeLvni, 2, m, &cPack_kBIeLvni_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_g3awnApV, 1, m, &cDelay_g3awnApV_sendMessage);
}

void Heavy_vSwell::cReceive_7TUdPCWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_rfqMdhPV, 2, m, &cPack_rfqMdhPV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ULuCTqlh, 1, m, &cDelay_ULuCTqlh_sendMessage);
}

void Heavy_vSwell::cReceive_eTjLPxJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EkB5m8uY, 1, m, &cVar_EkB5m8uY_sendMessage);
  cMsg_o1lgZdCq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zHaMYvIY, 1, m, &cVar_zHaMYvIY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ub2zRqjI, 1, m, &cVar_ub2zRqjI_sendMessage);
}

void Heavy_vSwell::cReceive_6RfggKbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jaegyV8c_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_jary6kJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_dKijF4UR_sendMessage);
}

void Heavy_vSwell::cReceive_Dxqf1mka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ygjR6yq2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_OUFLFBNi, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwell::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4;

  // input and output vars
  hv_bufferf_t O0;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_UEbsjOr1, VIf(I0));
    __hv_tabread_f(&sTabread_hkBzqMr5, VOf(Bf0));
    __hv_varread_f(&sVarf_bvRfZlHm, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_FmbjY9li, VOf(Bf2));
    __hv_rpole_f(&sRPole_VDG78TMH, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_OUFLFBNi, VOf(Bf1));
    __hv_varread_f(&sVarf_QhUI3HOE, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf3));
    __hv_gt_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_sqrt_f(VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_ePpyDEXp, VIf(Bf3), &sEnv_ePpyDEXp_sendMessage);
    __hv_line_f(&sLine_me8UX50f, VOf(Bf3));
    __hv_varread_f(&sVarf_8bMDQyyL, VOf(Bf1));
    __hv_pow_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Q8ZOr4ht, VOf(Bf3));
    __hv_max_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwell::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 1 channel(s)
  float **const bOut = &outputBuffers;

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwell::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 1 channel(s)
  float *const bOut = outputBuffers;

  int n = processInline(bIn, bOut, n4);

  

  return n;
}
