/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELL_HPP_
#define _HEAVY_CONTEXT_VSWELL_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvMath.h"
#include "HvSignalVar.h"
#include "HvSignalLine.h"
#include "HvControlDelay.h"
#include "HvControlCast.h"
#include "HvSignalTabwrite.h"
#include "HvTable.h"
#include "HvControlVar.h"
#include "HvControlIf.h"
#include "HvControlSlice.h"
#include "HvControlBinop.h"
#include "HvControlUnop.h"
#include "HvControlPack.h"
#include "HvControlTabhead.h"
#include "HvControlSystem.h"
#include "HvSignalTabread.h"
#include "HvSignalRPole.h"
#include "HvSignalEnvelope.h"
#include "HvSignalDel1.h"

class Heavy_vSwell : public HeavyContext {

 public:
  Heavy_vSwell(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwell();

  const char *getName() override { return "vSwell"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 1; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_BY_AUDIO_ON = 0xE7A7BB75, // Trigger_by_Audio_ON
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_ePpyDEXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pgK0iZ62_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Uu4Jj8aw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_IXt055CB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wjXJary9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HECLImbE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tfs5idit_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KdZSziUd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Nf5F6c2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GVtmPZGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EzyXmHhR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZClvd2qa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_jud13r1I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_DGRbILaT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yQoYWsh1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5lCY8zjd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ivd07cpZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5en8He67_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yRVwFP9r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k7kPqyP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ysawfSzr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9xKeAbxu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_A2LYequn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ubfY3lE3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DjMEg4Ar_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_tezDin9q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NApC7emK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jQ7MIox4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_P41wmj69_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XiFaXkH0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FMxrERt2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9tMyqUzq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BKtBN38F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_cfynjru7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_sAqqF38L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_9ipibQEh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kT9NfjCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_hOgGhZIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jFaPdohb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VR3gYaK7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lT3etGgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_E9ObS3Fz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_g1vHvQTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Y6VvpZz3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LVAdJGhY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CXnDcmRD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8OJV9QII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DQOpxDlT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RuJO8cpF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KVjLoxhX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uFH4JmGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YmVcmqtp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sesBpOeF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tcZrTjEr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_MW8oc8F7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jcKnbtfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a02nRgSW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_FPyrmsc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ub2zRqjI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tOZTiGqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_38U7EXYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CsJS5sIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QBuStfMh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EWS9pVKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6AVYkcjf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_g3awnApV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tBZzLyxV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LraupMBz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_kBIeLvni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GMFLd6EQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IuhJYfFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Pj1BS4Gw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jYcRBYve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y5LNTlEd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wR3jzt0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AKuSgbz1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ULuCTqlh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0mitxckj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gOZap9Lh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_rfqMdhPV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XRzMwq3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jriZLL9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_172F5S1r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_syHw9Gjf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YJuRNkJY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q1UPOY5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tg0VIbfj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YGGkG6ma_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_7wPcoCfF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zHaMYvIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EkB5m8uY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9eCRDIGe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xwkbDPsH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TN6cbJEU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_eWzXwy62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GYqy5YPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qINn6pjN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0atv6oo9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7aYBvT3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_at2k2tod_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pol6gPLF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w7MYjxlG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ZIjMUba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_X0VsF8Fz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sGNnA0BP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_HjH4tlco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qYREEGiP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_M5fKNfbg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_q5LA2RzL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_xJW9dQbA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Wiy9Qmm4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AvMzeZxA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RlzE475E_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_1qVl3J9l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IE5hjw3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BYVQ4Ra4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VWbRcNIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_3HezCOSF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_w29NZHPg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_suujtG7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O4y2LC2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zj2qWfAM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cdeHj2Im_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aVM9Uzo9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3rdsuzjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hiiPxlCo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qbiOGUhN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OO7PaYUm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iaqx4uIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GwJNeEMq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KxVMFRMi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1ZNy2BzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zQ146Hgh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tcyFtO51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tAJfbKpB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_na42v29B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QBkviOvR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q2hzGDqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7jHP0R6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_utMOPBRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zzjX7vCI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gwd7zb1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_geS9ed1b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZXbB0o9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YQKYa5CM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F2SclQpG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d7dnClct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3ZOzICy9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_NJO0oIIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_98Kw9RER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EE0F2QGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BDKSnSOD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ziuprGem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dw73zbi9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tKTNayme_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ti2NE1e8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ay69JyIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VPbTrBAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iMsFORiS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e2YnIfDJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_01lhIAmi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_MEOWplmm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MP5eADuI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_IBzlppnP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LTO94ZrC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_1VwpJ8Eb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_PXRgFI6A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5EoejoQP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v0HymPBi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KqMSFSDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7RTu2RHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b4TbwzJn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iyI7HJSb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_cDcl6iM9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YaI2dxea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_w8bbq0iI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oyiSRas3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_otpkRBlP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_O1vJ7wE9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_hkBzqMr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_umZzNCGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cV0GX30i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2ELgAXvC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_MGyDBC7f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jENjIq4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PmsR34Yb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WUky3Iqx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tnwAkLNK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RCHshgXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QIVPtMbg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gq5pDSO2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vjWr0W5L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_epwXeqpy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xiXQZJTb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8WtpYl8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6XUUT18t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_49nNpgFb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8mneE2nz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_sg2KSVYg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rUlgCHmi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o1lgZdCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HCAmlVin_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jaegyV8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dKijF4UR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ygjR6yq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5bF4ikBL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tmbtEAQ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HwyWST9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_prNePp7O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dUiyvnoW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6ZW2gXMk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QMiLNtoR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RbawrbhQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MiC3u1AM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AlQ9iANC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LSrNYoaD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_a88RFbQo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7TUdPCWq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eTjLPxJM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6RfggKbg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jary6kJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Dxqf1mka_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_UEbsjOr1;
  SignalTabread sTabread_hkBzqMr5;
  SignalRPole sRPole_VDG78TMH;
  SignalEnvelope sEnv_ePpyDEXp;
  SignalLine sLine_me8UX50f;
  ControlSlice cSlice_Uu4Jj8aw;
  ControlSlice cSlice_IXt055CB;
  ControlVar cVar_wjXJary9;
  ControlIf cIf_HECLImbE;
  ControlBinop cBinop_2Nf5F6c2;
  ControlSlice cSlice_jud13r1I;
  ControlSlice cSlice_DGRbILaT;
  ControlVar cVar_yQoYWsh1;
  ControlIf cIf_5lCY8zjd;
  ControlBinop cBinop_yRVwFP9r;
  ControlVar cVar_jQ7MIox4;
  ControlVar cVar_P41wmj69;
  ControlBinop cBinop_XiFaXkH0;
  ControlBinop cBinop_FMxrERt2;
  ControlSlice cSlice_cfynjru7;
  ControlSlice cSlice_sAqqF38L;
  ControlSlice cSlice_9ipibQEh;
  ControlVar cVar_kT9NfjCq;
  ControlIf cIf_VR3gYaK7;
  ControlBinop cBinop_lT3etGgk;
  ControlIf cIf_E9ObS3Fz;
  ControlIf cIf_g1vHvQTe;
  ControlIf cIf_Y6VvpZz3;
  ControlIf cIf_LVAdJGhY;
  ControlBinop cBinop_CXnDcmRD;
  ControlBinop cBinop_8OJV9QII;
  ControlBinop cBinop_DQOpxDlT;
  ControlBinop cBinop_sesBpOeF;
  ControlDelay cDelay_MW8oc8F7;
  ControlPack cPack_FPyrmsc3;
  ControlVar cVar_ub2zRqjI;
  ControlDelay cDelay_g3awnApV;
  ControlPack cPack_kBIeLvni;
  ControlVar cVar_GMFLd6EQ;
  ControlDelay cDelay_ULuCTqlh;
  ControlPack cPack_rfqMdhPV;
  ControlVar cVar_XRzMwq3t;
  ControlIf cIf_tg0VIbfj;
  ControlVar cVar_zHaMYvIY;
  ControlVar cVar_EkB5m8uY;
  SignalVarf sVarf_Q8ZOr4ht;
  ControlDelay cDelay_eWzXwy62;
  ControlVar cVar_7aYBvT3j;
  ControlBinop cBinop_pol6gPLF;
  ControlBinop cBinop_w7MYjxlG;
  ControlBinop cBinop_7ZIjMUba;
  ControlVar cVar_X0VsF8Fz;
  ControlSlice cSlice_q5LA2RzL;
  ControlSlice cSlice_xJW9dQbA;
  ControlVar cVar_Wiy9Qmm4;
  ControlVar cVar_AvMzeZxA;
  ControlVar cVar_IE5hjw3h;
  ControlVar cVar_BYVQ4Ra4;
  ControlVar cVar_VWbRcNIW;
  ControlSlice cSlice_3HezCOSF;
  ControlSlice cSlice_w29NZHPg;
  ControlBinop cBinop_suujtG7g;
  ControlBinop cBinop_O4y2LC2g;
  ControlBinop cBinop_Zj2qWfAM;
  ControlBinop cBinop_cdeHj2Im;
  ControlBinop cBinop_aVM9Uzo9;
  ControlBinop cBinop_qbiOGUhN;
  ControlBinop cBinop_OO7PaYUm;
  ControlBinop cBinop_iaqx4uIW;
  ControlBinop cBinop_GwJNeEMq;
  ControlBinop cBinop_QBkviOvR;
  ControlBinop cBinop_geS9ed1b;
  ControlDelay cDelay_NJO0oIIn;
  ControlVar cVar_BDKSnSOD;
  ControlBinop cBinop_tKTNayme;
  ControlBinop cBinop_ti2NE1e8;
  SignalVarf sVarf_FmbjY9li;
  ControlBinop cBinop_VPbTrBAe;
  ControlBinop cBinop_iMsFORiS;
  ControlBinop cBinop_e2YnIfDJ;
  SignalVarf sVarf_bvRfZlHm;
  ControlDelay cDelay_MP5eADuI;
  ControlDelay cDelay_IBzlppnP;
  ControlBinop cBinop_1VwpJ8Eb;
  HvTable hTable_PXRgFI6A;
  ControlBinop cBinop_v0HymPBi;
  ControlTabhead cTabhead_cDcl6iM9;
  ControlVar cVar_oyiSRas3;
  ControlDelay cDelay_otpkRBlP;
  ControlDelay cDelay_O1vJ7wE9;
  ControlBinop cBinop_umZzNCGC;
  ControlBinop cBinop_cV0GX30i;
  ControlBinop cBinop_2ELgAXvC;
  ControlBinop cBinop_tnwAkLNK;
  ControlBinop cBinop_QIVPtMbg;
  ControlBinop cBinop_Gq5pDSO2;
  ControlBinop cBinop_8mneE2nz;
  ControlBinop cBinop_rUlgCHmi;
  ControlBinop cBinop_dKijF4UR;
  ControlBinop cBinop_ygjR6yq2;
  SignalVarf sVarf_8bMDQyyL;
  SignalVarf sVarf_QhUI3HOE;
  SignalVarf sVarf_OUFLFBNi;
};

#endif // _HEAVY_CONTEXT_VSWELL_HPP_
