/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwellST.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwellST *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwellST_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwellST_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwellST_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwellST();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwellST::Heavy_vSwellST(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_x7gwvm2q, &hTable_XDjJa0C4);
  numBytes += sTabwrite_init(&sTabwrite_vlx4fURL, &hTable_0FBcSaBu);
  numBytes += sRPole_init(&sRPole_O8AGSfOh);
  numBytes += sEnv_init(&sEnv_gUsWxeh0, 1024, 512);
  numBytes += sTabread_init(&sTabread_z8HwKoId, &hTable_0FBcSaBu, true);
  numBytes += sLine_init(&sLine_r9VkSTZ4);
  numBytes += sTabread_init(&sTabread_kZ3bUXDe, &hTable_XDjJa0C4, true);
  numBytes += cSlice_init(&cSlice_aw10uD3e, 1, -1);
  numBytes += cSlice_init(&cSlice_RUl12IPO, 1, -1);
  numBytes += cVar_init_f(&cVar_bQ2F2dY4, 0.0f);
  numBytes += cIf_init(&cIf_KN5k3875, false);
  numBytes += cBinop_init(&cBinop_yjMOb7Sg, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_S0iA2PQm, 1, -1);
  numBytes += cSlice_init(&cSlice_IbwEVXOD, 1, -1);
  numBytes += cVar_init_f(&cVar_pM6g89ys, 0.0f);
  numBytes += cIf_init(&cIf_m1oOPMqq, false);
  numBytes += cBinop_init(&cBinop_RqwIFK1T, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_pOdLfsmt, 0.0f);
  numBytes += cVar_init_f(&cVar_JEKVS9yw, 0.0f);
  numBytes += cBinop_init(&cBinop_xbK2zwQ5, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_oOwYN5Rx, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_QliNNATN, 2, 1);
  numBytes += cSlice_init(&cSlice_37kJJdYz, 1, 1);
  numBytes += cSlice_init(&cSlice_S8NFZowF, 0, 1);
  numBytes += cVar_init_f(&cVar_IdmQds1R, 0.0f);
  numBytes += cIf_init(&cIf_cLk6LOH2, false);
  numBytes += cIf_init(&cIf_B7BasDX2, false);
  numBytes += cIf_init(&cIf_z8xoca5x, false);
  numBytes += cIf_init(&cIf_oPWXnxV4, false);
  numBytes += cIf_init(&cIf_JdJ89T7P, false);
  numBytes += cBinop_init(&cBinop_snb2xfvs, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_gwBmAgmz, 10.0f);
  numBytes += cPack_init(&cPack_JsO71lxA, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_4qFxva6l, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_kfpDxOS9, 10.0f);
  numBytes += cPack_init(&cPack_Czdgff4X, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_7MyQlMhq, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_uLQPrnea, 10.0f);
  numBytes += cPack_init(&cPack_uKgHSBUw, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_PedOmgBl, 1e-07f);
  numBytes += cVar_init_f(&cVar_xJRsVffH, 1e-07f);
  numBytes += cVar_init_f(&cVar_E6Ol3m30, 1e-07f);
  numBytes += sVarf_init(&sVarf_gnc6FYpy, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_RzyT96nf, 0.0f);
  numBytes += cVar_init_f(&cVar_YD6xjIZM, 20.0f);
  numBytes += cBinop_init(&cBinop_L9urN9KO, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_7hqJAekT, 0.0f);
  numBytes += cSlice_init(&cSlice_uItWb8kZ, 1, -1);
  numBytes += cSlice_init(&cSlice_3GPNXDsL, 1, -1);
  numBytes += cVar_init_f(&cVar_Vmeeh4xH, 0.0f);
  numBytes += cVar_init_f(&cVar_3TCCixqS, 20.0f);
  numBytes += cVar_init_f(&cVar_4VpNZNHv, 0.0f);
  numBytes += cVar_init_f(&cVar_hOdBN4Dn, 0.0f);
  numBytes += cVar_init_f(&cVar_MoYqvHry, 0.0f);
  numBytes += cSlice_init(&cSlice_SJmZOMP5, 1, 1);
  numBytes += cSlice_init(&cSlice_vGiqA3oE, 0, 1);
  numBytes += cBinop_init(&cBinop_pQrCnl58, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_16QSRGa1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gvDSKaCd, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_2gOEfgrq, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Uny8g2CB, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_JaQjFfVy, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_ZKrCW6jA, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_v1UyYQpq, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_CzDLDFDw, 5.0f);
  numBytes += cVar_init_f(&cVar_5LlewLkZ, 500.0f);
  numBytes += cBinop_init(&cBinop_QPPtRLjN, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_cesW93in, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vzS5QnFJ, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_ewsYIWOG, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Q5EDFoZF, 0.0f);
  numBytes += hTable_init(&hTable_XDjJa0C4, 256);
  numBytes += cTabhead_init(&cTabhead_hRuu4JDk, &hTable_XDjJa0C4);
  numBytes += cVar_init_s(&cVar_iqfKaa90, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_ftAY2io9, 8.0f);
  numBytes += cDelay_init(this, &cDelay_34U5UQNI, 0.0f);
  numBytes += cBinop_init(&cBinop_6HQJnT7m, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ee2soRol, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_atqBooRb, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_YQVTk2FI, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_TkvRv89c, 0.0f);
  numBytes += cDelay_init(this, &cDelay_m7UzWbLo, 0.0f);
  numBytes += hTable_init(&hTable_0FBcSaBu, 256);
  numBytes += cTabhead_init(&cTabhead_5VdwO6Bg, &hTable_0FBcSaBu);
  numBytes += cVar_init_s(&cVar_6fjvrPCZ, "del-1001-swell2");
  numBytes += cDelay_init(this, &cDelay_X30d48iX, 8.0f);
  numBytes += cDelay_init(this, &cDelay_cOg1vlzC, 0.0f);
  numBytes += cBinop_init(&cBinop_9ujzOWxo, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_8b6TRU0h, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_J1gIKo4i, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_4xEV5qtd, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_drQfNYIc, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_GVjG2h0E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mUGmAtMC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TfB6GCxp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pxiafd17, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kNZAgPim, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwellST::~Heavy_vSwellST() {
  sEnv_free(&sEnv_gUsWxeh0);
  cPack_free(&cPack_JsO71lxA);
  cPack_free(&cPack_Czdgff4X);
  cPack_free(&cPack_uKgHSBUw);
  hTable_free(&hTable_XDjJa0C4);
  hTable_free(&hTable_0FBcSaBu);
}

HvTable *Heavy_vSwellST::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_XDjJa0C4; // del-1001-swell
    case 0x505A9C79: return &hTable_0FBcSaBu; // del-1001-swell2
    default: return nullptr;
  }
}

void Heavy_vSwellST::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r54MDXp5_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tKFBAz8r_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jN3tskSk_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6lT76P8N_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bzjboTEc_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8K6gqhlw_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4TRVytNn_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2pL52fXy_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UBAFEZPH_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GQcirGuE_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8SoFQVMA_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qRSNH5I9_sendMessage);
      break;
    }
    case 0x4E6E7C40: { // Trigger_Left
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o4IC0neO_sendMessage);
      break;
    }
    case 0xB181ABB6: { // Trigger_Right
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_B6aEoZxk_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MpT7df8a_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YPg1wRxx_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OAzeyOqh_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_D5dedBqW_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwellST::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 20.0f;
        info->maxVal = 90.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_Left";
        info->hash = 0x4E6E7C40;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "Trigger_Right";
        info->hash = 0xB181ABB6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 14;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwellST::sEnv_gUsWxeh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xbK2zwQ5, HV_BINOP_GREATER_THAN, 0, m, &cBinop_xbK2zwQ5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oOwYN5Rx, HV_BINOP_LESS_THAN, 0, m, &cBinop_oOwYN5Rx_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_K5qLQttd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aw10uD3e, 0, m, &cSlice_aw10uD3e_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RUl12IPO, 0, m, &cSlice_RUl12IPO_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ycG7hJyD_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zCfa8Mwj_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_aw10uD3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_bQ2F2dY4, 0, m, &cVar_bQ2F2dY4_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_bQ2F2dY4, 0, m, &cVar_bQ2F2dY4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_RUl12IPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yjMOb7Sg, HV_BINOP_NEQ, 1, m, &cBinop_yjMOb7Sg_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_bQ2F2dY4, 1, m, &cVar_bQ2F2dY4_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yjMOb7Sg, HV_BINOP_NEQ, 1, m, &cBinop_yjMOb7Sg_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_bQ2F2dY4, 1, m, &cVar_bQ2F2dY4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_bQ2F2dY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7nC8EuFd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_KN5k3875_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FdcgSJmX_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rYlhgrVs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_rYlhgrVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bQ2F2dY4, 0, m, &cVar_bQ2F2dY4_sendMessage);
}

void Heavy_vSwellST::cCast_FdcgSJmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yjMOb7Sg, HV_BINOP_NEQ, 1, m, &cBinop_yjMOb7Sg_sendMessage);
}

void Heavy_vSwellST::cBinop_yjMOb7Sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KN5k3875, 1, m, &cIf_KN5k3875_sendMessage);
}

void Heavy_vSwellST::cCast_ycG7hJyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yjMOb7Sg, HV_BINOP_NEQ, 0, m, &cBinop_yjMOb7Sg_sendMessage);
}

void Heavy_vSwellST::cCast_zCfa8Mwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KN5k3875, 0, m, &cIf_KN5k3875_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_EO3cB723_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_S0iA2PQm, 0, m, &cSlice_S0iA2PQm_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IbwEVXOD, 0, m, &cSlice_IbwEVXOD_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iHOE72OP_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j10PlfTS_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_S0iA2PQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_pM6g89ys, 0, m, &cVar_pM6g89ys_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_pM6g89ys, 0, m, &cVar_pM6g89ys_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_IbwEVXOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_RqwIFK1T, HV_BINOP_NEQ, 1, m, &cBinop_RqwIFK1T_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_pM6g89ys, 1, m, &cVar_pM6g89ys_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_RqwIFK1T, HV_BINOP_NEQ, 1, m, &cBinop_RqwIFK1T_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_pM6g89ys, 1, m, &cVar_pM6g89ys_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_pM6g89ys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QrgTSmPA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_m1oOPMqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xcjthctW_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OWmKlql8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_xcjthctW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RqwIFK1T, HV_BINOP_NEQ, 1, m, &cBinop_RqwIFK1T_sendMessage);
}

void Heavy_vSwellST::cCast_OWmKlql8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pM6g89ys, 0, m, &cVar_pM6g89ys_sendMessage);
}

void Heavy_vSwellST::cBinop_RqwIFK1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m1oOPMqq, 1, m, &cIf_m1oOPMqq_sendMessage);
}

void Heavy_vSwellST::cCast_iHOE72OP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RqwIFK1T, HV_BINOP_NEQ, 0, m, &cBinop_RqwIFK1T_sendMessage);
}

void Heavy_vSwellST::cCast_j10PlfTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m1oOPMqq, 0, m, &cIf_m1oOPMqq_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_7nC8EuFd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqKW88oX_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V7lvjNXg_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_FqKW88oX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JEKVS9yw, 0, m, &cVar_JEKVS9yw_sendMessage);
}

void Heavy_vSwellST::cCast_V7lvjNXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VstcKVHo_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rlsws3fo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QmmzPDrJ_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_QrgTSmPA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SlHcdMMD_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ud6Y7rMh_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_SlHcdMMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pOdLfsmt, 0, m, &cVar_pOdLfsmt_sendMessage);
}

void Heavy_vSwellST::cCast_Ud6Y7rMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HrthSMBd_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_pOdLfsmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xbK2zwQ5, HV_BINOP_GREATER_THAN, 1, m, &cBinop_xbK2zwQ5_sendMessage);
}

void Heavy_vSwellST::cVar_JEKVS9yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oOwYN5Rx, HV_BINOP_LESS_THAN, 1, m, &cBinop_oOwYN5Rx_sendMessage);
}

void Heavy_vSwellST::cBinop_xbK2zwQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_K5qLQttd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_oOwYN5Rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EO3cB723_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_VstcKVHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xbK2zwQ5, HV_BINOP_GREATER_THAN, 1, m, &cBinop_xbK2zwQ5_sendMessage);
}

void Heavy_vSwellST::cMsg_HrthSMBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oOwYN5Rx, HV_BINOP_LESS_THAN, 1, m, &cBinop_oOwYN5Rx_sendMessage);
}

void Heavy_vSwellST::cSlice_QliNNATN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uUozz1BO_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_37kJJdYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_oPWXnxV4, 0, m, &cIf_oPWXnxV4_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_B7BasDX2, 0, m, &cIf_B7BasDX2_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_S8NFZowF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_JdJ89T7P, 0, m, &cIf_JdJ89T7P_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_z8xoca5x, 0, m, &cIf_z8xoca5x_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_IdmQds1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rOxHi1a6_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_cLk6LOH2, 0, m, &cIf_cLk6LOH2_sendMessage);
}

void Heavy_vSwellST::cUnop_y67nsPx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H21727lN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_snb2xfvs, HV_BINOP_EQ, 1, m, &cBinop_snb2xfvs_sendMessage);
}

void Heavy_vSwellST::cUnop_31PHqYry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H21727lN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_snb2xfvs, HV_BINOP_EQ, 1, m, &cBinop_snb2xfvs_sendMessage);
}

void Heavy_vSwellST::cIf_cLk6LOH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_31PHqYry_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_y67nsPx8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_rOxHi1a6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cLk6LOH2, 1, m, &cIf_cLk6LOH2_sendMessage);
}

void Heavy_vSwellST::cIf_B7BasDX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IOddS4cY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_z8xoca5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_oPWXnxV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IOddS4cY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_JdJ89T7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_uUozz1BO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_snb2xfvs, HV_BINOP_EQ, 0, m, &cBinop_snb2xfvs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_TEiV24Qz_sendMessage);
}

void Heavy_vSwellST::cBinop_H21727lN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G9ZBmJ6m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g8lVZPpk_sendMessage);
}

void Heavy_vSwellST::cBinop_snb2xfvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SvuHVHkW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6RSkKqvF_sendMessage);
}

void Heavy_vSwellST::cCast_6RSkKqvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JdJ89T7P, 1, m, &cIf_JdJ89T7P_sendMessage);
}

void Heavy_vSwellST::cCast_SvuHVHkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B7BasDX2, 1, m, &cIf_B7BasDX2_sendMessage);
}

void Heavy_vSwellST::cCast_g8lVZPpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z8xoca5x, 1, m, &cIf_z8xoca5x_sendMessage);
}

void Heavy_vSwellST::cCast_G9ZBmJ6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oPWXnxV4, 1, m, &cIf_oPWXnxV4_sendMessage);
}

void Heavy_vSwellST::cBinop_TEiV24Qz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwellST::cSwitchcase_sDKEt6WY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UqNu1tTJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UqNu1tTJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gwBmAgmz, 1, m, &cDelay_gwBmAgmz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2aN2UG9w_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_gwBmAgmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gwBmAgmz, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G6gOvhRf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tRgQdVIj_sendMessage);
  cSwitchcase_GmvbYQ4A_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_UqNu1tTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gwBmAgmz, 0, m, &cDelay_gwBmAgmz_sendMessage);
}

void Heavy_vSwellST::cCast_2aN2UG9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gwBmAgmz, 0, m, &cDelay_gwBmAgmz_sendMessage);
}

void Heavy_vSwellST::cPack_JsO71lxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g0o2VCm7_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_4qFxva6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pbRDG0wI_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_6ZU5mZDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_sDKEt6WY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_Hx3pvj4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_JsO71lxA, 0, m, &cPack_JsO71lxA_sendMessage);
}

void Heavy_vSwellST::cCast_ihFwpe2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4qFxva6l, 0, m, &cVar_4qFxva6l_sendMessage);
}

void Heavy_vSwellST::cMsg_pbRDG0wI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_r9VkSTZ4, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_g0o2VCm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_r9VkSTZ4, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_GmvbYQ4A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aztjHp1A_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aztjHp1A_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kfpDxOS9, 1, m, &cDelay_kfpDxOS9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_klTNmARB_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_kfpDxOS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kfpDxOS9, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kKWeMtQX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fNBXMoOC_sendMessage);
  cSwitchcase_1u3y1Ma4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_aztjHp1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kfpDxOS9, 0, m, &cDelay_kfpDxOS9_sendMessage);
}

void Heavy_vSwellST::cCast_klTNmARB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kfpDxOS9, 0, m, &cDelay_kfpDxOS9_sendMessage);
}

void Heavy_vSwellST::cPack_Czdgff4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dMVVpAIT_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_7MyQlMhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4FjBZILp_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_fKgHudwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_GmvbYQ4A_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_tRgQdVIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Czdgff4X, 0, m, &cPack_Czdgff4X_sendMessage);
}

void Heavy_vSwellST::cCast_G6gOvhRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7MyQlMhq, 0, m, &cVar_7MyQlMhq_sendMessage);
}

void Heavy_vSwellST::cMsg_4FjBZILp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_r9VkSTZ4, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_dMVVpAIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_r9VkSTZ4, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_1u3y1Ma4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qIXnMIps_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qIXnMIps_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uLQPrnea, 1, m, &cDelay_uLQPrnea_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ElK16keG_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_uLQPrnea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uLQPrnea, m);
}

void Heavy_vSwellST::cMsg_qIXnMIps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uLQPrnea, 0, m, &cDelay_uLQPrnea_sendMessage);
}

void Heavy_vSwellST::cCast_ElK16keG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uLQPrnea, 0, m, &cDelay_uLQPrnea_sendMessage);
}

void Heavy_vSwellST::cPack_uKgHSBUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OTYTnKPd_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_PedOmgBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NovGuoHk_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_m7eVUEv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_1u3y1Ma4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_kKWeMtQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PedOmgBl, 0, m, &cVar_PedOmgBl_sendMessage);
}

void Heavy_vSwellST::cCast_fNBXMoOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_uKgHSBUw, 0, m, &cPack_uKgHSBUw_sendMessage);
}

void Heavy_vSwellST::cMsg_NovGuoHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_r9VkSTZ4, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_OTYTnKPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_r9VkSTZ4, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_JJ0hGXrD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0m0nXNzS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_0m0nXNzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rlsws3fo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QmmzPDrJ_sendMessage);
}

void Heavy_vSwellST::cVar_xJRsVffH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KFen8dNN_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_E6Ol3m30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_uKgHSBUw, 1, m, &cPack_uKgHSBUw_sendMessage);
}

void Heavy_vSwellST::cMsg_rvnYvqBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BemvQydH_sendMessage);
}

void Heavy_vSwellST::cSystem_BemvQydH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_16QSRGa1, HV_BINOP_MULTIPLY, 1, m, &cBinop_16QSRGa1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pQrCnl58, HV_BINOP_MULTIPLY, 1, m, &cBinop_pQrCnl58_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_Shc0DBw0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_8eTUmIJ8_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_8eTUmIJ8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HunD3CtZ_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_RzyT96nf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RzyT96nf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RzyT96nf, 0, m, &cDelay_RzyT96nf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7hqJAekT, 0, m, &cVar_7hqJAekT_sendMessage);
}

void Heavy_vSwellST::cCast_HunD3CtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8eTUmIJ8_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RzyT96nf, 0, m, &cDelay_RzyT96nf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7hqJAekT, 0, m, &cVar_7hqJAekT_sendMessage);
}

void Heavy_vSwellST::cMsg_F4BMbDOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1HB6KErg_sendMessage);
}

void Heavy_vSwellST::cSystem_1HB6KErg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BVMCYL1o_sendMessage);
}

void Heavy_vSwellST::cVar_YD6xjIZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L9urN9KO, HV_BINOP_MULTIPLY, 0, m, &cBinop_L9urN9KO_sendMessage);
}

void Heavy_vSwellST::cMsg_8eTUmIJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RzyT96nf, 0, m, &cDelay_RzyT96nf_sendMessage);
}

void Heavy_vSwellST::cBinop_MMXCEHat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RzyT96nf, 2, m, &cDelay_RzyT96nf_sendMessage);
}

void Heavy_vSwellST::cBinop_BVMCYL1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L9urN9KO, HV_BINOP_MULTIPLY, 1, m, &cBinop_L9urN9KO_sendMessage);
}

void Heavy_vSwellST::cBinop_L9urN9KO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_MMXCEHat_sendMessage);
}

void Heavy_vSwellST::cVar_7hqJAekT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gvDSKaCd, HV_BINOP_SUBTRACT, 0, m, &cBinop_gvDSKaCd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_GDmokJGn_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_ibgQ3QiA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l7A6nPlo_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gn6q0901_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_l7A6nPlo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MoYqvHry, 0, m, &cVar_MoYqvHry_sendMessage);
}

void Heavy_vSwellST::cCast_Gn6q0901_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HuSUPDZP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QerL64Sq_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_SrAEYdqk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uItWb8kZ, 0, m, &cSlice_uItWb8kZ_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3GPNXDsL, 0, m, &cSlice_3GPNXDsL_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EP8Rotyy_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_SJmZOMP5, 0, m, &cSlice_SJmZOMP5_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_vGiqA3oE, 0, m, &cSlice_vGiqA3oE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UUNm6asb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GLhrJq2Z_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_uItWb8kZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_D4AtMl8j_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_D4AtMl8j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_3GPNXDsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6yA3Sg2S_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Wicu6QX_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6yA3Sg2S_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Wicu6QX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_Vmeeh4xH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OdA7fzoY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZWOxXVj0_sendMessage);
}

void Heavy_vSwellST::cVar_3TCCixqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xu3xdOuW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_xu3xdOuW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cP23Igke_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_16QSRGa1, HV_BINOP_MULTIPLY, 0, m, &cBinop_16QSRGa1_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_Uny8g2CB, HV_BINOP_DIVIDE, 1, m, &cBinop_Uny8g2CB_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_YD6xjIZM, 0, m, &cVar_YD6xjIZM_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cCast_cP23Igke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w2tBL3nQ_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_4VpNZNHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v1UyYQpq, HV_BINOP_SUBTRACT, 1, m, &cBinop_v1UyYQpq_sendMessage);
}

void Heavy_vSwellST::cVar_hOdBN4Dn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MoYqvHry, 0, m, &cVar_MoYqvHry_sendMessage);
}

void Heavy_vSwellST::cVar_MoYqvHry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2gOEfgrq, HV_BINOP_ADD, 0, m, &cBinop_2gOEfgrq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZKrCW6jA, HV_BINOP_ADD, 0, m, &cBinop_ZKrCW6jA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gnc6FYpy, m);
}

void Heavy_vSwellST::cSlice_SJmZOMP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OdA7fzoY_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZWOxXVj0_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_vGiqA3oE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7iEbdyc3_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XVkBdw9x_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_V9sT38aS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7hqJAekT, 1, m, &cVar_7hqJAekT_sendMessage);
}

void Heavy_vSwellST::cBinop_pQrCnl58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_V9sT38aS_sendMessage);
}

void Heavy_vSwellST::cBinop_16QSRGa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7dTB27oP_sendMessage);
}

void Heavy_vSwellST::cBinop_7dTB27oP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gvDSKaCd, HV_BINOP_SUBTRACT, 1, m, &cBinop_gvDSKaCd_sendMessage);
}

void Heavy_vSwellST::cBinop_gvDSKaCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7hqJAekT, 1, m, &cVar_7hqJAekT_sendMessage);
}

void Heavy_vSwellST::cMsg_4jDxRzyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_Shc0DBw0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_PxHGUPsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_Shc0DBw0_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZKrCW6jA, HV_BINOP_ADD, 1, m, &cBinop_ZKrCW6jA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2gOEfgrq, HV_BINOP_ADD, 1, m, &cBinop_2gOEfgrq_sendMessage);
}

void Heavy_vSwellST::cBinop_GDmokJGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ibgQ3QiA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_2gOEfgrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MoYqvHry, 1, m, &cVar_MoYqvHry_sendMessage);
}

void Heavy_vSwellST::cBinop_Uny8g2CB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JaQjFfVy, HV_BINOP_DIVIDE, 1, m, &cBinop_JaQjFfVy_sendMessage);
}

void Heavy_vSwellST::cBinop_JaQjFfVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZKrCW6jA, HV_BINOP_ADD, 1, m, &cBinop_ZKrCW6jA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2gOEfgrq, HV_BINOP_ADD, 1, m, &cBinop_2gOEfgrq_sendMessage);
}

void Heavy_vSwellST::cCast_OdA7fzoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pQrCnl58, HV_BINOP_MULTIPLY, 0, m, &cBinop_pQrCnl58_sendMessage);
}

void Heavy_vSwellST::cCast_ZWOxXVj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Uny8g2CB, HV_BINOP_DIVIDE, 0, m, &cBinop_Uny8g2CB_sendMessage);
}

void Heavy_vSwellST::cCast_XVkBdw9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v1UyYQpq, HV_BINOP_SUBTRACT, 0, m, &cBinop_v1UyYQpq_sendMessage);
}

void Heavy_vSwellST::cCast_7iEbdyc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hOdBN4Dn, 1, m, &cVar_hOdBN4Dn_sendMessage);
}

void Heavy_vSwellST::cCast_QerL64Sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hOdBN4Dn, 0, m, &cVar_hOdBN4Dn_sendMessage);
}

void Heavy_vSwellST::cCast_HuSUPDZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PxHGUPsd_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_ZKrCW6jA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4VpNZNHv, 0, m, &cVar_4VpNZNHv_sendMessage);
}

void Heavy_vSwellST::cMsg_D4AtMl8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_Shc0DBw0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_bGybt7NR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Vmeeh4xH, 1, m, &cVar_Vmeeh4xH_sendMessage);
}

void Heavy_vSwellST::cMsg_w2tBL3nQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_16QSRGa1, HV_BINOP_MULTIPLY, 0, m, &cBinop_16QSRGa1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Uny8g2CB, HV_BINOP_DIVIDE, 1, m, &cBinop_Uny8g2CB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YD6xjIZM, 0, m, &cVar_YD6xjIZM_sendMessage);
}

void Heavy_vSwellST::cCast_9Wicu6QX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qqF0fmkt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZKrCW6jA, HV_BINOP_ADD, 0, m, &cBinop_ZKrCW6jA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MoYqvHry, 1, m, &cVar_MoYqvHry_sendMessage);
}

void Heavy_vSwellST::cCast_6yA3Sg2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D4AtMl8j_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_v1UyYQpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JaQjFfVy, HV_BINOP_DIVIDE, 0, m, &cBinop_JaQjFfVy_sendMessage);
}

void Heavy_vSwellST::cCast_qqF0fmkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PxHGUPsd_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_EP8Rotyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Vmeeh4xH, 0, m, &cVar_Vmeeh4xH_sendMessage);
}

void Heavy_vSwellST::cCast_GLhrJq2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bGybt7NR_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_UUNm6asb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4jDxRzyQ_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_OkcPqGbv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UV8PuyO3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UV8PuyO3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CzDLDFDw, 1, m, &cDelay_CzDLDFDw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r0zgo0dN_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_CzDLDFDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CzDLDFDw, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ihFwpe2S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hx3pvj4q_sendMessage);
  cSwitchcase_sDKEt6WY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_UV8PuyO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CzDLDFDw, 0, m, &cDelay_CzDLDFDw_sendMessage);
}

void Heavy_vSwellST::cCast_r0zgo0dN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CzDLDFDw, 0, m, &cDelay_CzDLDFDw_sendMessage);
}

void Heavy_vSwellST::cVar_5LlewLkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QPPtRLjN, HV_BINOP_MULTIPLY, 0, m, &cBinop_QPPtRLjN_sendMessage);
}

void Heavy_vSwellST::cMsg_UBdHYEgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_W3LvYurp_sendMessage);
}

void Heavy_vSwellST::cSystem_W3LvYurp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7MJIOX5d_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_QPPtRLjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_23m0TpkP_sendMessage);
}

void Heavy_vSwellST::cBinop_9KgkybRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QPPtRLjN, HV_BINOP_MULTIPLY, 1, m, &cBinop_QPPtRLjN_sendMessage);
}

void Heavy_vSwellST::cMsg_7MJIOX5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9KgkybRH_sendMessage);
}

void Heavy_vSwellST::cBinop_23m0TpkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KPnDCShj_sendMessage);
}

void Heavy_vSwellST::cBinop_KPnDCShj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kQL2KLa8_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vzS5QnFJ, m);
}

void Heavy_vSwellST::cBinop_kQL2KLa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cesW93in, m);
}

void Heavy_vSwellST::cMsg_8XDztCl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mVkCCaCW_sendMessage);
}

void Heavy_vSwellST::cSystem_mVkCCaCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ixoUbz2P_sendMessage);
}

void Heavy_vSwellST::cDelay_ewsYIWOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ewsYIWOG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q5EDFoZF, 0, m, &cDelay_Q5EDFoZF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ewsYIWOG, 0, m, &cDelay_ewsYIWOG_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_x7gwvm2q, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_Q5EDFoZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q5EDFoZF, m);
  cMsg_G2sQWqFH_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_f1FZlKny_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_kOjj0ncr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_effFVXnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SYC87CCf_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_XDjJa0C4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sx0sgtn1_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ewsYIWOG, 2, m, &cDelay_ewsYIWOG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dnt4r3YD_sendMessage);
}

void Heavy_vSwellST::cMsg_SYC87CCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_XDjJa0C4, 0, m, &hTable_XDjJa0C4_sendMessage);
}

void Heavy_vSwellST::cBinop_ixoUbz2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_effFVXnm_sendMessage);
}

void Heavy_vSwellST::cMsg_G2sQWqFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_XDjJa0C4, 0, m, &hTable_XDjJa0C4_sendMessage);
}

void Heavy_vSwellST::cCast_Dnt4r3YD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ewsYIWOG, 0, m, &cDelay_ewsYIWOG_sendMessage);
}

void Heavy_vSwellST::cMsg_sx0sgtn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q5EDFoZF, 2, m, &cDelay_Q5EDFoZF_sendMessage);
}

void Heavy_vSwellST::cMsg_kOjj0ncr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_x7gwvm2q, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_hRuu4JDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ee2soRol, HV_BINOP_SUBTRACT, 0, m, &cBinop_Ee2soRol_sendMessage);
}

void Heavy_vSwellST::cMsg_mWL3Op9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AGin1QZs_sendMessage);
}

void Heavy_vSwellST::cSystem_AGin1QZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_SW2nfOrX_sendMessage);
}

void Heavy_vSwellST::cVar_iqfKaa90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rhBmYUI2_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_ftAY2io9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ftAY2io9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_34U5UQNI, 0, m, &cDelay_34U5UQNI_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_kZ3bUXDe, 0, m, &sTabread_kZ3bUXDe_sendMessage);
}

void Heavy_vSwellST::cDelay_34U5UQNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_34U5UQNI, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_kZ3bUXDe, 0, m, &sTabread_kZ3bUXDe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_34U5UQNI, 0, m, &cDelay_34U5UQNI_sendMessage);
}

void Heavy_vSwellST::sTabread_kZ3bUXDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_YQVTk2FI, HV_BINOP_SUBTRACT, 0, m, &cBinop_YQVTk2FI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_6HQJnT7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_atqBooRb, HV_BINOP_MAX, 0, m, &cBinop_atqBooRb_sendMessage);
}

void Heavy_vSwellST::cBinop_SW2nfOrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6HQJnT7m, HV_BINOP_MULTIPLY, 0, m, &cBinop_6HQJnT7m_sendMessage);
}

void Heavy_vSwellST::cBinop_Ee2soRol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4r4qzB4E_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_kZ3bUXDe, 0, m, &sTabread_kZ3bUXDe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jZUBGBXG_sendMessage);
}

void Heavy_vSwellST::cSystem_DNX3ebNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YQVTk2FI, HV_BINOP_SUBTRACT, 1, m, &cBinop_YQVTk2FI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_34U5UQNI, 2, m, &cDelay_34U5UQNI_sendMessage);
}

void Heavy_vSwellST::cMsg_rhBmYUI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DNX3ebNI_sendMessage);
}

void Heavy_vSwellST::cMsg_4r4qzB4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ftAY2io9, 0, m, &cDelay_ftAY2io9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_34U5UQNI, 0, m, &cDelay_34U5UQNI_sendMessage);
}

void Heavy_vSwellST::cMsg_5bcZ5nre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_atqBooRb, HV_BINOP_MAX, 1, m, &cBinop_atqBooRb_sendMessage);
}

void Heavy_vSwellST::cBinop_atqBooRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ee2soRol, HV_BINOP_SUBTRACT, 1, m, &cBinop_Ee2soRol_sendMessage);
}

void Heavy_vSwellST::cCast_jZUBGBXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ftAY2io9, 0, m, &cDelay_ftAY2io9_sendMessage);
}

void Heavy_vSwellST::cBinop_0GwODWOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ftAY2io9, 2, m, &cDelay_ftAY2io9_sendMessage);
}

void Heavy_vSwellST::cBinop_YQVTk2FI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0GwODWOX_sendMessage);
}

void Heavy_vSwellST::cCast_lorJaMa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iqfKaa90, 0, m, &cVar_iqfKaa90_sendMessage);
  cMsg_mWL3Op9b_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hRuu4JDk, 0, m, &cTabhead_hRuu4JDk_sendMessage);
}

void Heavy_vSwellST::cMsg_Xbfu8zCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_anxhVaaB_sendMessage);
}

void Heavy_vSwellST::cSystem_anxhVaaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2gsVzOgM_sendMessage);
}

void Heavy_vSwellST::cDelay_TkvRv89c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TkvRv89c, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_m7UzWbLo, 0, m, &cDelay_m7UzWbLo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TkvRv89c, 0, m, &cDelay_TkvRv89c_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_vlx4fURL, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_m7UzWbLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_m7UzWbLo, m);
  cMsg_lC8at99s_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_VC5nrMmX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_AQb2VR76_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_jQvIspS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wffXOdZe_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_0FBcSaBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rfmvUWcX_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TkvRv89c, 2, m, &cDelay_TkvRv89c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cu69qfkP_sendMessage);
}

void Heavy_vSwellST::cMsg_wffXOdZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_0FBcSaBu, 0, m, &hTable_0FBcSaBu_sendMessage);
}

void Heavy_vSwellST::cBinop_2gsVzOgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_jQvIspS8_sendMessage);
}

void Heavy_vSwellST::cMsg_lC8at99s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_0FBcSaBu, 0, m, &hTable_0FBcSaBu_sendMessage);
}

void Heavy_vSwellST::cCast_cu69qfkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TkvRv89c, 0, m, &cDelay_TkvRv89c_sendMessage);
}

void Heavy_vSwellST::cMsg_rfmvUWcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_m7UzWbLo, 2, m, &cDelay_m7UzWbLo_sendMessage);
}

void Heavy_vSwellST::cMsg_AQb2VR76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_vlx4fURL, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_5VdwO6Bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8b6TRU0h, HV_BINOP_SUBTRACT, 0, m, &cBinop_8b6TRU0h_sendMessage);
}

void Heavy_vSwellST::cMsg_OiZ1TxfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8ts5d2LU_sendMessage);
}

void Heavy_vSwellST::cSystem_8ts5d2LU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_a6yL2Vjp_sendMessage);
}

void Heavy_vSwellST::cVar_6fjvrPCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R8yzYE8Q_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_X30d48iX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_X30d48iX, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cOg1vlzC, 0, m, &cDelay_cOg1vlzC_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_z8HwKoId, 0, m, &sTabread_z8HwKoId_sendMessage);
}

void Heavy_vSwellST::cDelay_cOg1vlzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cOg1vlzC, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_z8HwKoId, 0, m, &sTabread_z8HwKoId_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cOg1vlzC, 0, m, &cDelay_cOg1vlzC_sendMessage);
}

void Heavy_vSwellST::sTabread_z8HwKoId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_4xEV5qtd, HV_BINOP_SUBTRACT, 0, m, &cBinop_4xEV5qtd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_9ujzOWxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J1gIKo4i, HV_BINOP_MAX, 0, m, &cBinop_J1gIKo4i_sendMessage);
}

void Heavy_vSwellST::cBinop_a6yL2Vjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9ujzOWxo, HV_BINOP_MULTIPLY, 0, m, &cBinop_9ujzOWxo_sendMessage);
}

void Heavy_vSwellST::cBinop_8b6TRU0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AVgpHDGq_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_z8HwKoId, 0, m, &sTabread_z8HwKoId_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ghHJF7Rk_sendMessage);
}

void Heavy_vSwellST::cSystem_xDSLRg5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4xEV5qtd, HV_BINOP_SUBTRACT, 1, m, &cBinop_4xEV5qtd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cOg1vlzC, 2, m, &cDelay_cOg1vlzC_sendMessage);
}

void Heavy_vSwellST::cMsg_R8yzYE8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xDSLRg5R_sendMessage);
}

void Heavy_vSwellST::cMsg_AVgpHDGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_X30d48iX, 0, m, &cDelay_X30d48iX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cOg1vlzC, 0, m, &cDelay_cOg1vlzC_sendMessage);
}

void Heavy_vSwellST::cMsg_El68HArG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_J1gIKo4i, HV_BINOP_MAX, 1, m, &cBinop_J1gIKo4i_sendMessage);
}

void Heavy_vSwellST::cBinop_J1gIKo4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8b6TRU0h, HV_BINOP_SUBTRACT, 1, m, &cBinop_8b6TRU0h_sendMessage);
}

void Heavy_vSwellST::cCast_ghHJF7Rk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_X30d48iX, 0, m, &cDelay_X30d48iX_sendMessage);
}

void Heavy_vSwellST::cBinop_InW8MfP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_X30d48iX, 2, m, &cDelay_X30d48iX_sendMessage);
}

void Heavy_vSwellST::cBinop_4xEV5qtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_InW8MfP3_sendMessage);
}

void Heavy_vSwellST::cCast_3SvLCZ7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6fjvrPCZ, 0, m, &cVar_6fjvrPCZ_sendMessage);
  cMsg_OiZ1TxfA_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5VdwO6Bg, 0, m, &cTabhead_5VdwO6Bg_sendMessage);
}

void Heavy_vSwellST::cUnop_zrJzh4ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pxiafd17, m);
}

void Heavy_vSwellST::cCast_QmmzPDrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OkcPqGbv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_rlsws3fo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rI07aQgF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xJRsVffH, 0, m, &cVar_xJRsVffH_sendMessage);
}

void Heavy_vSwellST::cCast_cjsQRQYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_drQfNYIc, HV_BINOP_SUBTRACT, 0, m, &cBinop_drQfNYIc_sendMessage);
}

void Heavy_vSwellST::cCast_nq6AQWrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pOdLfsmt, 0, m, &cVar_pOdLfsmt_sendMessage);
}

void Heavy_vSwellST::cBinop_drQfNYIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JEKVS9yw, 0, m, &cVar_JEKVS9yw_sendMessage);
}

void Heavy_vSwellST::cSend_rI07aQgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OAzeyOqh_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_IOddS4cY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JJ0hGXrD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_ocfq7GJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_SrAEYdqk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_KFen8dNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r9VkSTZ4, 0, m, NULL);
}

void Heavy_vSwellST::cSend_Lc2BrSU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_D5dedBqW_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_6G9mRuid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CzDLDFDw, 1, m, &cDelay_CzDLDFDw_sendMessage);
}

void Heavy_vSwellST::cBinop_Ff9XQ0mj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_zrJzh4ew_sendMessage);
}

void Heavy_vSwellST::cReceive_UBAFEZPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_drQfNYIc, HV_BINOP_SUBTRACT, 1, m, &cBinop_drQfNYIc_sendMessage);
}

void Heavy_vSwellST::cReceive_MpT7df8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F4BMbDOb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YD6xjIZM, 0, m, &cVar_YD6xjIZM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IdmQds1R, 0, m, &cVar_IdmQds1R_sendMessage);
  cMsg_rvnYvqBD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4VpNZNHv, 0, m, &cVar_4VpNZNHv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3TCCixqS, 0, m, &cVar_3TCCixqS_sendMessage);
  cMsg_UBdHYEgf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5LlewLkZ, 0, m, &cVar_5LlewLkZ_sendMessage);
  cMsg_8XDztCl6_sendMessage(_c, 0, m);
  cMsg_Xbfu8zCM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_E6Ol3m30, 0, m, &cVar_E6Ol3m30_sendMessage);
  cMsg_5bcZ5nre_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_iqfKaa90, 0, m, &cVar_iqfKaa90_sendMessage);
  cMsg_mWL3Op9b_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hRuu4JDk, 0, m, &cTabhead_hRuu4JDk_sendMessage);
  cMsg_El68HArG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6fjvrPCZ, 0, m, &cVar_6fjvrPCZ_sendMessage);
  cMsg_OiZ1TxfA_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5VdwO6Bg, 0, m, &cTabhead_5VdwO6Bg_sendMessage);
}

void Heavy_vSwellST::cReceive_YPg1wRxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_QliNNATN, 0, m, &cSlice_QliNNATN_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_37kJJdYz, 0, m, &cSlice_37kJJdYz_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_S8NFZowF, 0, m, &cSlice_S8NFZowF_sendMessage);
}

void Heavy_vSwellST::cReceive_8K6gqhlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GVjG2h0E, m);
}

void Heavy_vSwellST::cReceive_OAzeyOqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6ZU5mZDM_sendMessage(_c, 0, m);
  cMsg_fKgHudwn_sendMessage(_c, 0, m);
  cMsg_m7eVUEv4_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_qRSNH5I9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rlsws3fo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QmmzPDrJ_sendMessage);
}

void Heavy_vSwellST::cReceive_r54MDXp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7MyQlMhq, 1, m, &cVar_7MyQlMhq_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_JsO71lxA, 1, m, &cPack_JsO71lxA_sendMessage);
}

void Heavy_vSwellST::cReceive_tKFBAz8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_JsO71lxA, 2, m, &cPack_JsO71lxA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gwBmAgmz, 1, m, &cDelay_gwBmAgmz_sendMessage);
}

void Heavy_vSwellST::cReceive_jN3tskSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Czdgff4X, 1, m, &cPack_Czdgff4X_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PedOmgBl, 1, m, &cVar_PedOmgBl_sendMessage);
}

void Heavy_vSwellST::cReceive_6lT76P8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Czdgff4X, 2, m, &cPack_Czdgff4X_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kfpDxOS9, 1, m, &cDelay_kfpDxOS9_sendMessage);
}

void Heavy_vSwellST::cReceive_bzjboTEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_uKgHSBUw, 2, m, &cPack_uKgHSBUw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uLQPrnea, 1, m, &cDelay_uLQPrnea_sendMessage);
}

void Heavy_vSwellST::cReceive_D5dedBqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E6Ol3m30, 1, m, &cVar_E6Ol3m30_sendMessage);
  cMsg_ocfq7GJH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xJRsVffH, 1, m, &cVar_xJRsVffH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4qFxva6l, 1, m, &cVar_4qFxva6l_sendMessage);
}

void Heavy_vSwellST::cReceive_4TRVytNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Lc2BrSU4_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_8SoFQVMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_6G9mRuid_sendMessage);
}

void Heavy_vSwellST::cReceive_o4IC0neO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mUGmAtMC, m);
}

void Heavy_vSwellST::cReceive_B6aEoZxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TfB6GCxp, m);
}

void Heavy_vSwellST::cReceive_2pL52fXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cjsQRQYn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nq6AQWrc_sendMessage);
}

void Heavy_vSwellST::cReceive_GQcirGuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Ff9XQ0mj_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kNZAgPim, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwellST::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_x7gwvm2q, VIf(I0));
    __hv_tabwrite_f(&sTabwrite_vlx4fURL, VIf(I1));
    __hv_varread_f(&sVarf_mUGmAtMC, VOf(Bf0));
    __hv_varread_f(&sVarf_TfB6GCxp, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_vzS5QnFJ, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_cesW93in, VOf(Bf1));
    __hv_rpole_f(&sRPole_O8AGSfOh, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_kNZAgPim, VOf(Bf0));
    __hv_varread_f(&sVarf_pxiafd17, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf2));
    __hv_gt_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_sqrt_f(VIf(Bf3), VOf(Bf3));
    __hv_and_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf2), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_gUsWxeh0, VIf(Bf2), &sEnv_gUsWxeh0_sendMessage);
    __hv_tabread_f(&sTabread_z8HwKoId, VOf(Bf2));
    __hv_line_f(&sLine_r9VkSTZ4, VOf(Bf0));
    __hv_varread_f(&sVarf_GVjG2h0E, VOf(Bf1));
    __hv_pow_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_gnc6FYpy, VOf(Bf0));
    __hv_max_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_tabread_f(&sTabread_kZ3bUXDe, VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwellST::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwellST::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
