/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELLST_HPP_
#define _HEAVY_CONTEXT_VSWELLST_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalEnvelope.h"
#include "HvControlUnop.h"
#include "HvMath.h"
#include "HvSignalDel1.h"
#include "HvTable.h"
#include "HvSignalLine.h"
#include "HvSignalVar.h"
#include "HvControlBinop.h"
#include "HvControlTabhead.h"
#include "HvSignalTabwrite.h"
#include "HvControlSlice.h"
#include "HvControlIf.h"
#include "HvSignalRPole.h"
#include "HvSignalTabread.h"
#include "HvControlDelay.h"
#include "HvControlSystem.h"
#include "HvControlCast.h"
#include "HvControlPack.h"
#include "HvControlVar.h"

class Heavy_vSwellST : public HeavyContext {

 public:
  Heavy_vSwellST(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwellST();

  const char *getName() override { return "vSwellST"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_LEFT = 0x4E6E7C40, // Trigger_Left
        TRIGGER_RIGHT = 0xB181ABB6, // Trigger_Right
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_gUsWxeh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_K5qLQttd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_aw10uD3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_RUl12IPO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bQ2F2dY4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KN5k3875_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rYlhgrVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FdcgSJmX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yjMOb7Sg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ycG7hJyD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zCfa8Mwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EO3cB723_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_S0iA2PQm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_IbwEVXOD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pM6g89ys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_m1oOPMqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xcjthctW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OWmKlql8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RqwIFK1T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iHOE72OP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j10PlfTS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7nC8EuFd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_FqKW88oX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V7lvjNXg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QrgTSmPA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_SlHcdMMD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ud6Y7rMh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pOdLfsmt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JEKVS9yw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xbK2zwQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oOwYN5Rx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VstcKVHo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HrthSMBd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_QliNNATN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_37kJJdYz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_S8NFZowF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IdmQds1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_y67nsPx8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_31PHqYry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cLk6LOH2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rOxHi1a6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_B7BasDX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_z8xoca5x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oPWXnxV4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JdJ89T7P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uUozz1BO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H21727lN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_snb2xfvs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6RSkKqvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SvuHVHkW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g8lVZPpk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G9ZBmJ6m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TEiV24Qz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sDKEt6WY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_gwBmAgmz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UqNu1tTJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2aN2UG9w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_JsO71lxA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4qFxva6l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6ZU5mZDM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Hx3pvj4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ihFwpe2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pbRDG0wI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g0o2VCm7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GmvbYQ4A_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_kfpDxOS9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aztjHp1A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_klTNmARB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Czdgff4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7MyQlMhq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fKgHudwn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tRgQdVIj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G6gOvhRf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4FjBZILp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dMVVpAIT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1u3y1Ma4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_uLQPrnea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qIXnMIps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ElK16keG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_uKgHSBUw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PedOmgBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m7eVUEv4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kKWeMtQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fNBXMoOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NovGuoHk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OTYTnKPd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JJ0hGXrD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_0m0nXNzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xJRsVffH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_E6Ol3m30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rvnYvqBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_BemvQydH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Shc0DBw0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_RzyT96nf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HunD3CtZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F4BMbDOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1HB6KErg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YD6xjIZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8eTUmIJ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MMXCEHat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BVMCYL1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L9urN9KO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7hqJAekT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ibgQ3QiA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_l7A6nPlo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gn6q0901_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SrAEYdqk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_uItWb8kZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_3GPNXDsL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Vmeeh4xH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3TCCixqS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xu3xdOuW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_cP23Igke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4VpNZNHv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hOdBN4Dn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MoYqvHry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_SJmZOMP5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_vGiqA3oE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V9sT38aS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pQrCnl58_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_16QSRGa1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7dTB27oP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gvDSKaCd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4jDxRzyQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PxHGUPsd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GDmokJGn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2gOEfgrq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uny8g2CB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JaQjFfVy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OdA7fzoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZWOxXVj0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XVkBdw9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7iEbdyc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QerL64Sq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HuSUPDZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZKrCW6jA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D4AtMl8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bGybt7NR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w2tBL3nQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9Wicu6QX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6yA3Sg2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v1UyYQpq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qqF0fmkt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EP8Rotyy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GLhrJq2Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UUNm6asb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OkcPqGbv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_CzDLDFDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UV8PuyO3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r0zgo0dN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5LlewLkZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UBdHYEgf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_W3LvYurp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QPPtRLjN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9KgkybRH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7MJIOX5d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_23m0TpkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KPnDCShj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kQL2KLa8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8XDztCl6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mVkCCaCW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ewsYIWOG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Q5EDFoZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_f1FZlKny_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_effFVXnm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_XDjJa0C4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SYC87CCf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ixoUbz2P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G2sQWqFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Dnt4r3YD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sx0sgtn1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kOjj0ncr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_hRuu4JDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mWL3Op9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AGin1QZs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iqfKaa90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ftAY2io9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_34U5UQNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_kZ3bUXDe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6HQJnT7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SW2nfOrX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ee2soRol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DNX3ebNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rhBmYUI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4r4qzB4E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5bcZ5nre_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_atqBooRb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jZUBGBXG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0GwODWOX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YQVTk2FI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lorJaMa4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xbfu8zCM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_anxhVaaB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TkvRv89c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_m7UzWbLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VC5nrMmX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_jQvIspS8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_0FBcSaBu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wffXOdZe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2gsVzOgM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lC8at99s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cu69qfkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rfmvUWcX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AQb2VR76_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_5VdwO6Bg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OiZ1TxfA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8ts5d2LU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6fjvrPCZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_X30d48iX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_cOg1vlzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_z8HwKoId_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9ujzOWxo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a6yL2Vjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8b6TRU0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xDSLRg5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R8yzYE8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AVgpHDGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_El68HArG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J1gIKo4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ghHJF7Rk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_InW8MfP3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4xEV5qtd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3SvLCZ7H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_zrJzh4ew_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QmmzPDrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rlsws3fo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cjsQRQYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nq6AQWrc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_drQfNYIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rI07aQgF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IOddS4cY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ocfq7GJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KFen8dNN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Lc2BrSU4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6G9mRuid_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ff9XQ0mj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UBAFEZPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MpT7df8a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YPg1wRxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8K6gqhlw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OAzeyOqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qRSNH5I9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_r54MDXp5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tKFBAz8r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jN3tskSk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6lT76P8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bzjboTEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_D5dedBqW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4TRVytNn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8SoFQVMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_o4IC0neO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_B6aEoZxk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2pL52fXy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GQcirGuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_x7gwvm2q;
  SignalTabwrite sTabwrite_vlx4fURL;
  SignalRPole sRPole_O8AGSfOh;
  SignalEnvelope sEnv_gUsWxeh0;
  SignalTabread sTabread_z8HwKoId;
  SignalLine sLine_r9VkSTZ4;
  SignalTabread sTabread_kZ3bUXDe;
  ControlSlice cSlice_aw10uD3e;
  ControlSlice cSlice_RUl12IPO;
  ControlVar cVar_bQ2F2dY4;
  ControlIf cIf_KN5k3875;
  ControlBinop cBinop_yjMOb7Sg;
  ControlSlice cSlice_S0iA2PQm;
  ControlSlice cSlice_IbwEVXOD;
  ControlVar cVar_pM6g89ys;
  ControlIf cIf_m1oOPMqq;
  ControlBinop cBinop_RqwIFK1T;
  ControlVar cVar_pOdLfsmt;
  ControlVar cVar_JEKVS9yw;
  ControlBinop cBinop_xbK2zwQ5;
  ControlBinop cBinop_oOwYN5Rx;
  ControlSlice cSlice_QliNNATN;
  ControlSlice cSlice_37kJJdYz;
  ControlSlice cSlice_S8NFZowF;
  ControlVar cVar_IdmQds1R;
  ControlIf cIf_cLk6LOH2;
  ControlBinop cBinop_rOxHi1a6;
  ControlIf cIf_B7BasDX2;
  ControlIf cIf_z8xoca5x;
  ControlIf cIf_oPWXnxV4;
  ControlIf cIf_JdJ89T7P;
  ControlBinop cBinop_uUozz1BO;
  ControlBinop cBinop_H21727lN;
  ControlBinop cBinop_snb2xfvs;
  ControlBinop cBinop_TEiV24Qz;
  ControlDelay cDelay_gwBmAgmz;
  ControlPack cPack_JsO71lxA;
  ControlVar cVar_4qFxva6l;
  ControlDelay cDelay_kfpDxOS9;
  ControlPack cPack_Czdgff4X;
  ControlVar cVar_7MyQlMhq;
  ControlDelay cDelay_uLQPrnea;
  ControlPack cPack_uKgHSBUw;
  ControlVar cVar_PedOmgBl;
  ControlVar cVar_xJRsVffH;
  ControlVar cVar_E6Ol3m30;
  SignalVarf sVarf_gnc6FYpy;
  ControlDelay cDelay_RzyT96nf;
  ControlVar cVar_YD6xjIZM;
  ControlBinop cBinop_MMXCEHat;
  ControlBinop cBinop_BVMCYL1o;
  ControlBinop cBinop_L9urN9KO;
  ControlVar cVar_7hqJAekT;
  ControlSlice cSlice_uItWb8kZ;
  ControlSlice cSlice_3GPNXDsL;
  ControlVar cVar_Vmeeh4xH;
  ControlVar cVar_3TCCixqS;
  ControlVar cVar_4VpNZNHv;
  ControlVar cVar_hOdBN4Dn;
  ControlVar cVar_MoYqvHry;
  ControlSlice cSlice_SJmZOMP5;
  ControlSlice cSlice_vGiqA3oE;
  ControlBinop cBinop_V9sT38aS;
  ControlBinop cBinop_pQrCnl58;
  ControlBinop cBinop_16QSRGa1;
  ControlBinop cBinop_7dTB27oP;
  ControlBinop cBinop_gvDSKaCd;
  ControlBinop cBinop_GDmokJGn;
  ControlBinop cBinop_2gOEfgrq;
  ControlBinop cBinop_Uny8g2CB;
  ControlBinop cBinop_JaQjFfVy;
  ControlBinop cBinop_ZKrCW6jA;
  ControlBinop cBinop_v1UyYQpq;
  ControlDelay cDelay_CzDLDFDw;
  ControlVar cVar_5LlewLkZ;
  ControlBinop cBinop_QPPtRLjN;
  ControlBinop cBinop_9KgkybRH;
  SignalVarf sVarf_cesW93in;
  ControlBinop cBinop_23m0TpkP;
  ControlBinop cBinop_KPnDCShj;
  ControlBinop cBinop_kQL2KLa8;
  SignalVarf sVarf_vzS5QnFJ;
  ControlDelay cDelay_ewsYIWOG;
  ControlDelay cDelay_Q5EDFoZF;
  ControlBinop cBinop_effFVXnm;
  HvTable hTable_XDjJa0C4;
  ControlBinop cBinop_ixoUbz2P;
  ControlTabhead cTabhead_hRuu4JDk;
  ControlVar cVar_iqfKaa90;
  ControlDelay cDelay_ftAY2io9;
  ControlDelay cDelay_34U5UQNI;
  ControlBinop cBinop_6HQJnT7m;
  ControlBinop cBinop_SW2nfOrX;
  ControlBinop cBinop_Ee2soRol;
  ControlBinop cBinop_atqBooRb;
  ControlBinop cBinop_0GwODWOX;
  ControlBinop cBinop_YQVTk2FI;
  ControlDelay cDelay_TkvRv89c;
  ControlDelay cDelay_m7UzWbLo;
  ControlBinop cBinop_jQvIspS8;
  HvTable hTable_0FBcSaBu;
  ControlBinop cBinop_2gsVzOgM;
  ControlTabhead cTabhead_5VdwO6Bg;
  ControlVar cVar_6fjvrPCZ;
  ControlDelay cDelay_X30d48iX;
  ControlDelay cDelay_cOg1vlzC;
  ControlBinop cBinop_9ujzOWxo;
  ControlBinop cBinop_a6yL2Vjp;
  ControlBinop cBinop_8b6TRU0h;
  ControlBinop cBinop_J1gIKo4i;
  ControlBinop cBinop_InW8MfP3;
  ControlBinop cBinop_4xEV5qtd;
  ControlBinop cBinop_drQfNYIc;
  ControlBinop cBinop_IOddS4cY;
  ControlBinop cBinop_6G9mRuid;
  ControlBinop cBinop_Ff9XQ0mj;
  SignalVarf sVarf_GVjG2h0E;
  SignalVarf sVarf_mUGmAtMC;
  SignalVarf sVarf_TfB6GCxp;
  SignalVarf sVarf_pxiafd17;
  SignalVarf sVarf_kNZAgPim;
};

#endif // _HEAVY_CONTEXT_VSWELLST_HPP_
